"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .createapikeyresponse import CreateAPIKeyResponse, CreateAPIKeyResponseTypedDict
from factify.types import BaseModel
from typing import Dict, List
from typing_extensions import TypedDict


class CreateAPIKeyResponseResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: CreateAPIKeyResponseTypedDict


class CreateAPIKeyResponseResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: CreateAPIKeyResponse
