"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from factify.types import BaseModel
from typing_extensions import TypedDict


class TrashDocumentResponseTypedDict(TypedDict):
    r"""TrashDocumentResponse is empty on success."""


class TrashDocumentResponse(BaseModel):
    r"""TrashDocumentResponse is empty on success."""
