"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from typing import Any, Dict, List, Union
from typing_extensions import TypeAliasType


ValueTypedDict = TypeAliasType(
    "ValueTypedDict", Union[float, str, bool, List[Any], Dict[str, Any]]
)
r"""`Value` represents a dynamically typed value which can be either
null, a number, a string, a boolean, a recursive struct value, or a
list of values. A producer of value is expected to set one of these
variants. Absence of any variant indicates an error.

The JSON representation for `Value` is JSON value.
"""


Value = TypeAliasType("Value", Union[float, str, bool, List[Any], Dict[str, Any]])
r"""`Value` represents a dynamically typed value which can be either
null, a number, a string, a boolean, a recursive struct value, or a
list of values. A producer of value is expected to set one of these
variants. Absence of any variant indicates an error.

The JSON representation for `Value` is JSON value.
"""
