"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .generateentrypageresponse import (
    GenerateEntryPageResponse,
    GenerateEntryPageResponseTypedDict,
)
from factify.types import BaseModel
from factify.utils import FieldMetadata, PathParamMetadata
from typing import Dict, List
from typing_extensions import Annotated, TypedDict


class GenerateDocumentEntryPageRequestTypedDict(TypedDict):
    document_id: str
    r"""Document ID.
    Pattern: doc_[0-9a-hjkmnp-tv-z]{26}
    """


class GenerateDocumentEntryPageRequest(BaseModel):
    document_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""Document ID.
    Pattern: doc_[0-9a-hjkmnp-tv-z]{26}
    """


class GenerateDocumentEntryPageResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: GenerateEntryPageResponseTypedDict


class GenerateDocumentEntryPageResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: GenerateEntryPageResponse
