"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .documentrole import DocumentRole
from .recipienttype import RecipientType
from factify.types import BaseModel, UNSET_SENTINEL
from pydantic import model_serializer
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class RecipientTypedDict(TypedDict):
    r"""Recipient represents an entity with access to a document."""

    document_role: DocumentRole
    id: str
    r"""Recipient ID (TypeID: user_xxx, bot_xxx, or org_xxx)."""
    type: RecipientType
    email: NotRequired[str]
    r"""Email (only for user recipients)."""
    name: NotRequired[str]
    r"""Display name."""


class Recipient(BaseModel):
    r"""Recipient represents an entity with access to a document."""

    document_role: DocumentRole

    id: str
    r"""Recipient ID (TypeID: user_xxx, bot_xxx, or org_xxx)."""

    type: RecipientType

    email: Optional[str] = None
    r"""Email (only for user recipients)."""

    name: Optional[str] = None
    r"""Display name."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["email", "name"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m
