"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from datetime import datetime
from factify.types import BaseModel, UNSET_SENTINEL
from pydantic import model_serializer
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class ShareLinkTypedDict(TypedDict):
    r"""ShareLink represents a shareable link for a document."""

    created_at: NotRequired[datetime]
    r"""When the link was created."""
    creator_id: NotRequired[str]
    r"""ID of the user who created this link."""
    document_id: NotRequired[str]
    r"""Document ID this link belongs to."""
    id: NotRequired[str]
    r"""Share link ID."""


class ShareLink(BaseModel):
    r"""ShareLink represents a shareable link for a document."""

    created_at: Optional[datetime] = None
    r"""When the link was created."""

    creator_id: Optional[str] = None
    r"""ID of the user who created this link."""

    document_id: Optional[str] = None
    r"""Document ID this link belongs to."""

    id: Optional[str] = None
    r"""Share link ID."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["created_at", "creator_id", "document_id", "id"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m
