"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .timelineevent import TimelineEvent, TimelineEventTypedDict
from factify.types import BaseModel, Nullable, OptionalNullable, UNSET, UNSET_SENTINEL
from pydantic import model_serializer
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class GetTimelineResponseTypedDict(TypedDict):
    events: NotRequired[List[TimelineEventTypedDict]]
    has_more: NotRequired[bool]
    next_cursor: NotRequired[Nullable[str]]


class GetTimelineResponse(BaseModel):
    events: Optional[List[TimelineEvent]] = None

    has_more: Optional[bool] = None

    next_cursor: OptionalNullable[str] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["events", "has_more", "next_cursor"])
        nullable_fields = set(["next_cursor"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m
