"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .untrashdocumentresponse import (
    UntrashDocumentResponse,
    UntrashDocumentResponseTypedDict,
)
from factify.types import BaseModel
from factify.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing import Dict, List
from typing_extensions import Annotated, TypedDict


class UntrashDocumentUntrashDocumentRequestTypedDict(TypedDict):
    r"""UntrashDocumentRequest identifies the document to restore."""


class UntrashDocumentUntrashDocumentRequest(BaseModel):
    r"""UntrashDocumentRequest identifies the document to restore."""


class UntrashDocumentRequestTypedDict(TypedDict):
    document_id: str
    r"""Document ID."""
    body: UntrashDocumentUntrashDocumentRequestTypedDict


class UntrashDocumentRequest(BaseModel):
    document_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""Document ID."""

    body: Annotated[
        UntrashDocumentUntrashDocumentRequest,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]


class UntrashDocumentResponseResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: UntrashDocumentResponseTypedDict


class UntrashDocumentResponseResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: UntrashDocumentResponse
