"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from factify.types import BaseModel, UNSET_SENTINEL
from pydantic import model_serializer
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class PaginationTypedDict(TypedDict):
    r"""Pagination contains cursor-based pagination metadata.
    Follows Google AIP-158 for pagination field naming.
    """

    has_more: NotRequired[bool]
    r"""Whether there are more results in the forward direction."""
    next_page_token: NotRequired[str]
    r"""Token to retrieve the next page of results.
    Empty if there are no more results in the forward direction.
    """
    prev_page_token: NotRequired[str]
    r"""Token to retrieve the previous page of results.
    Empty if this is the first page.
    """


class Pagination(BaseModel):
    r"""Pagination contains cursor-based pagination metadata.
    Follows Google AIP-158 for pagination field naming.
    """

    has_more: Optional[bool] = None
    r"""Whether there are more results in the forward direction."""

    next_page_token: Optional[str] = None
    r"""Token to retrieve the next page of results.
    Empty if there are no more results in the forward direction.
    """

    prev_page_token: Optional[str] = None
    r"""Token to retrieve the previous page of results.
    Empty if this is the first page.
    """

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["has_more", "next_page_token", "prev_page_token"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m
