"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from factify.types import BaseModel
from typing_extensions import TypedDict


class RemoveOrganizationMemberResponseTypedDict(TypedDict):
    r"""RemoveOrganizationMemberResponse is empty on success."""


class RemoveOrganizationMemberResponse(BaseModel):
    r"""RemoveOrganizationMemberResponse is empty on success."""
