"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from factify.types import BaseModel, UNSET_SENTINEL
from pydantic import model_serializer
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class GetDocumentQuotaResponseTypedDict(TypedDict):
    r"""GetDocumentQuotaResponse contains the document quota for the organization."""

    available: NotRequired[int]
    r"""Remaining documents that can be created (limit minus used, floored at 0).
    When limit is 0 (unlimited), this field is 0 and should be ignored by clients.
    """
    limit: NotRequired[int]
    r"""Maximum documents allowed for this organization.
    0 means unlimited (no quota enforced).
    """
    used: NotRequired[int]
    r"""Number of documents counting against quota (excludes demo, includes trashed)."""


class GetDocumentQuotaResponse(BaseModel):
    r"""GetDocumentQuotaResponse contains the document quota for the organization."""

    available: Optional[int] = None
    r"""Remaining documents that can be created (limit minus used, floored at 0).
    When limit is 0 (unlimited), this field is 0 and should be ignored by clients.
    """

    limit: Optional[int] = None
    r"""Maximum documents allowed for this organization.
    0 means unlimited (no quota enforced).
    """

    used: Optional[int] = None
    r"""Number of documents counting against quota (excludes demo, includes trashed)."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["available", "limit", "used"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m
