"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from datetime import datetime
from factify.types import BaseModel, UNSET_SENTINEL
from pydantic import model_serializer
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class APIKeyTypedDict(TypedDict):
    r"""ApiKey represents an authentication credential for programmatic API access."""

    created_at: datetime
    r"""Timestamp when the key was created."""
    id: str
    r"""Unique ID for the API key.
    Pattern: key_[0-9a-hjkmnp-tv-z]{26}
    """
    is_active: bool
    r"""Whether the key is currently active (not revoked and not expired).
    Computed: is_active = (revoked_at == null) && (expires_at == null || expires_at > now())
    """
    key_prefix: str
    r"""Truncated key prefix for identification in UI (e.g., \"ffy_prod_01jd4h5...\").
    Shows the first 16 characters for better uniqueness while maintaining security.
    """
    name: str
    r"""Human-readable name for the key (e.g., \"Production\", \"Staging\")."""
    organization_id: str
    r"""ID of the organization this key belongs to.
    Pattern: org_[0-9a-hjkmnp-tv-z]{26}
    """
    expires_at: NotRequired[datetime]
    r"""Expiration timestamp. If set, the key becomes invalid after this time."""
    revoked_at: NotRequired[datetime]
    r"""Timestamp when the key was revoked. Null if the key has not been revoked."""


class APIKey(BaseModel):
    r"""ApiKey represents an authentication credential for programmatic API access."""

    created_at: datetime
    r"""Timestamp when the key was created."""

    id: str
    r"""Unique ID for the API key.
    Pattern: key_[0-9a-hjkmnp-tv-z]{26}
    """

    is_active: bool
    r"""Whether the key is currently active (not revoked and not expired).
    Computed: is_active = (revoked_at == null) && (expires_at == null || expires_at > now())
    """

    key_prefix: str
    r"""Truncated key prefix for identification in UI (e.g., \"ffy_prod_01jd4h5...\").
    Shows the first 16 characters for better uniqueness while maintaining security.
    """

    name: str
    r"""Human-readable name for the key (e.g., \"Production\", \"Staging\")."""

    organization_id: str
    r"""ID of the organization this key belongs to.
    Pattern: org_[0-9a-hjkmnp-tv-z]{26}
    """

    expires_at: Optional[datetime] = None
    r"""Expiration timestamp. If set, the key becomes invalid after this time."""

    revoked_at: Optional[datetime] = None
    r"""Timestamp when the key was revoked. Null if the key has not been revoked."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["expires_at", "revoked_at"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m
