"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from factify.types import BaseModel
from typing_extensions import TypedDict


class EmptyTypedDict(TypedDict):
    r"""A generic empty message that you can re-use to avoid defining duplicated
    empty messages in your APIs. A typical example is to use it as the request
    or the response type of an API method. For instance:

    service Foo {
    rpc Bar(google.protobuf.Empty) returns (google.protobuf.Empty);
    }
    """


class Empty(BaseModel):
    r"""A generic empty message that you can re-use to avoid defining duplicated
    empty messages in your APIs. A typical example is to use it as the request
    or the response type of an API method. For instance:

    service Foo {
    rpc Bar(google.protobuf.Empty) returns (google.protobuf.Empty);
    }
    """
