"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .removeorganizationmemberresponse import (
    RemoveOrganizationMemberResponse,
    RemoveOrganizationMemberResponseTypedDict,
)
from factify.types import BaseModel
from factify.utils import FieldMetadata, PathParamMetadata
from typing import Dict, List
from typing_extensions import Annotated, TypedDict


class RemoveOrganizationMemberRequestTypedDict(TypedDict):
    organization_id: str
    r"""Organization to remove the member from.
    Pattern: org_[0-9a-hjkmnp-tv-z]{26}
    """
    user_id: str
    r"""User account ID of the member to remove.
    Pattern: user_[0-9a-hjkmnp-tv-z]{26}
    """


class RemoveOrganizationMemberRequest(BaseModel):
    organization_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""Organization to remove the member from.
    Pattern: org_[0-9a-hjkmnp-tv-z]{26}
    """

    user_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""User account ID of the member to remove.
    Pattern: user_[0-9a-hjkmnp-tv-z]{26}
    """


class RemoveOrganizationMemberResponseResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: RemoveOrganizationMemberResponseTypedDict


class RemoveOrganizationMemberResponseResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: RemoveOrganizationMemberResponse
