"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from factify.types import BaseModel
from typing_extensions import TypedDict


class GenerateEntryPageResponseTypedDict(TypedDict):
    r"""GenerateEntryPageResponse contains the download URL for the entry page."""

    download_url: str
    r"""Temporary download URL for the entry page PDF."""


class GenerateEntryPageResponse(BaseModel):
    r"""GenerateEntryPageResponse contains the download URL for the entry page."""

    download_url: str
    r"""Temporary download URL for the entry page PDF."""
