"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .trashdocumentresponse import TrashDocumentResponse, TrashDocumentResponseTypedDict
from factify.types import BaseModel
from factify.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing import Dict, List
from typing_extensions import Annotated, TypedDict


class TrashDocumentTrashDocumentRequestTypedDict(TypedDict):
    r"""TrashDocumentRequest identifies the document to trash."""


class TrashDocumentTrashDocumentRequest(BaseModel):
    r"""TrashDocumentRequest identifies the document to trash."""


class TrashDocumentRequestTypedDict(TypedDict):
    document_id: str
    r"""Document ID."""
    body: TrashDocumentTrashDocumentRequestTypedDict


class TrashDocumentRequest(BaseModel):
    document_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""Document ID."""

    body: Annotated[
        TrashDocumentTrashDocumentRequest,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]


class TrashDocumentResponseResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: TrashDocumentResponseTypedDict


class TrashDocumentResponseResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: TrashDocumentResponse
