"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .getmeresponse import GetMeResponse, GetMeResponseTypedDict
from factify.types import BaseModel
from typing import Dict, List
from typing_extensions import TypedDict


class GetMeResponseResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: GetMeResponseTypedDict


class GetMeResponseResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: GetMeResponse
