"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from typing import Literal


TimelineEventType = Literal[
    "TIMELINE_EVENT_TYPE_UNSPECIFIED",
    "TIMELINE_EVENT_TYPE_COMMENT_CREATED",
    "TIMELINE_EVENT_TYPE_COMMENT_UPDATED",
    "TIMELINE_EVENT_TYPE_THREAD_CREATED",
    "TIMELINE_EVENT_TYPE_THREAD_UPDATED",
    "TIMELINE_EVENT_TYPE_APPROVAL_VOTED",
    "TIMELINE_EVENT_TYPE_APPROVAL_STARTED",
    "TIMELINE_EVENT_TYPE_APPROVAL_TERMINATED",
    "TIMELINE_EVENT_TYPE_DOCUMENT_LOADED",
    "TIMELINE_EVENT_TYPE_APPROVAL_READY",
    "TIMELINE_EVENT_TYPE_APPROVAL_SUBMITTED",
    "TIMELINE_EVENT_TYPE_APPROVAL_SKIP_DISSEMINATION",
    "TIMELINE_EVENT_TYPE_DOCUMENT_CREATED",
    "TIMELINE_EVENT_TYPE_DOCUMENT_UPDATED",
    "TIMELINE_EVENT_TYPE_COMMENT_DELETED",
    "TIMELINE_EVENT_TYPE_DOCUMENT_USER_ACCESS_GRANTED",
    "TIMELINE_EVENT_TYPE_DOCUMENT_USER_ACCESS_REVOKED",
    "TIMELINE_EVENT_TYPE_DOCUMENT_ENTRY_PAGE_DOWNLOADED",
    "TIMELINE_EVENT_TYPE_DOCUMENT_VERSION_UPLOADED",
    "TIMELINE_EVENT_TYPE_DOCUMENT_PRINTED",
    "TIMELINE_EVENT_TYPE_DOCUMENT_SETTINGS_ACCESS_CHANGED",
    "TIMELINE_EVENT_TYPE_ANNOTATION_ADDED",
    "TIMELINE_EVENT_TYPE_ANNOTATION_EDITED",
    "TIMELINE_EVENT_TYPE_ANNOTATION_DELETED",
    "TIMELINE_EVENT_TYPE_ANNOTATION_RESOLVED",
]
