"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .approveaccessrequestresponse import (
    ApproveAccessRequestResponse,
    ApproveAccessRequestResponseTypedDict,
)
from factify.types import BaseModel
from factify.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing import Dict, List
from typing_extensions import Annotated, TypedDict


class ApproveAccessRequestApproveAccessRequestRequestTypedDict(TypedDict):
    r"""ApproveAccessRequestRequest approves an access request."""


class ApproveAccessRequestApproveAccessRequestRequest(BaseModel):
    r"""ApproveAccessRequestRequest approves an access request."""


class ApproveAccessRequestRequestTypedDict(TypedDict):
    document_id: str
    r"""Document ID."""
    access_request_id: str
    r"""Access request ID to approve."""
    body: ApproveAccessRequestApproveAccessRequestRequestTypedDict


class ApproveAccessRequestRequest(BaseModel):
    document_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""Document ID."""

    access_request_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""Access request ID to approve."""

    body: Annotated[
        ApproveAccessRequestApproveAccessRequestRequest,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]


class ApproveAccessRequestResponseResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: ApproveAccessRequestResponseTypedDict


class ApproveAccessRequestResponseResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: ApproveAccessRequestResponse
