"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .accessrequest import AccessRequest, AccessRequestTypedDict
from factify.types import BaseModel
from typing_extensions import TypedDict


class ApproveAccessRequestResponseTypedDict(TypedDict):
    r"""ApproveAccessRequestResponse contains the approved access request."""

    access_request: AccessRequestTypedDict
    r"""AccessRequest represents a request for access to a document."""


class ApproveAccessRequestResponse(BaseModel):
    r"""ApproveAccessRequestResponse contains the approved access request."""

    access_request: AccessRequest
    r"""AccessRequest represents a request for access to a document."""
