"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from datetime import datetime
from factify.types import BaseModel, Nullable, OptionalNullable, UNSET, UNSET_SENTINEL
from pydantic import model_serializer
from typing_extensions import NotRequired, TypedDict


class OrganizationTypedDict(TypedDict):
    r"""Organization represents a Factify organization."""

    created_at: datetime
    r"""Timestamp when the organization was created."""
    id: str
    r"""Unique ID for the organization.
    Pattern: org_[0-9a-hjkmnp-tv-z]{26}
    """
    name: str
    r"""Human-readable organization name."""
    logo_image_url: NotRequired[Nullable[str]]
    r"""Optional — organizations may not have a logo."""


class Organization(BaseModel):
    r"""Organization represents a Factify organization."""

    created_at: datetime
    r"""Timestamp when the organization was created."""

    id: str
    r"""Unique ID for the organization.
    Pattern: org_[0-9a-hjkmnp-tv-z]{26}
    """

    name: str
    r"""Human-readable organization name."""

    logo_image_url: OptionalNullable[str] = UNSET
    r"""Optional — organizations may not have a logo."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["logo_image_url"])
        nullable_fields = set(["logo_image_url"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m
