"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .checkaccessrequeststatusresponse import (
    CheckAccessRequestStatusResponse,
    CheckAccessRequestStatusResponseTypedDict,
)
from factify.types import BaseModel
from factify.utils import FieldMetadata, PathParamMetadata
from typing import Dict, List
from typing_extensions import Annotated, TypedDict


class CheckAccessRequestStatusRequestTypedDict(TypedDict):
    document_id: str
    r"""Document ID."""


class CheckAccessRequestStatusRequest(BaseModel):
    document_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""Document ID."""


class CheckAccessRequestStatusResponseResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: CheckAccessRequestStatusResponseTypedDict


class CheckAccessRequestStatusResponseResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: CheckAccessRequestStatusResponse
