"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from typing import Any, TYPE_CHECKING

from factify.utils.dynamic_imports import lazy_getattr, lazy_dir

if TYPE_CHECKING:
    from .acceptorganizationinviteop import (
        AcceptOrganizationInviteAcceptOrganizationInviteRequest,
        AcceptOrganizationInviteAcceptOrganizationInviteRequestTypedDict,
        AcceptOrganizationInviteRequest,
        AcceptOrganizationInviteRequestTypedDict,
        AcceptOrganizationInviteResponseResponse,
        AcceptOrganizationInviteResponseResponseTypedDict,
    )
    from .acceptorganizationinviteresponse import (
        AcceptOrganizationInviteResponse,
        AcceptOrganizationInviteResponseTypedDict,
    )
    from .accessgrantresult import AccessGrantResult, AccessGrantResultTypedDict
    from .accesslevel import AccessLevel
    from .accessrequest import AccessRequest, AccessRequestTypedDict
    from .accessrequestpermission import AccessRequestPermission
    from .accessrequeststatus import AccessRequestStatus
    from .addorganizationmemberop import (
        AddOrganizationMemberAddOrganizationMemberRequest,
        AddOrganizationMemberAddOrganizationMemberRequestTypedDict,
        AddOrganizationMemberRequest,
        AddOrganizationMemberRequestTypedDict,
        AddOrganizationMemberResponseResponse,
        AddOrganizationMemberResponseResponseTypedDict,
    )
    from .addorganizationmemberresponse import (
        AddOrganizationMemberResponse,
        AddOrganizationMemberResponseTypedDict,
    )
    from .apikey import APIKey, APIKeyTypedDict
    from .apikeyquota import APIKeyQuota, APIKeyQuotaTypedDict
    from .approveaccessrequestop import (
        ApproveAccessRequestApproveAccessRequestRequest,
        ApproveAccessRequestApproveAccessRequestRequestTypedDict,
        ApproveAccessRequestRequest,
        ApproveAccessRequestRequestTypedDict,
        ApproveAccessRequestResponseResponse,
        ApproveAccessRequestResponseResponseTypedDict,
    )
    from .approveaccessrequestresponse import (
        ApproveAccessRequestResponse,
        ApproveAccessRequestResponseTypedDict,
    )
    from .attachdocumentpolicyop import (
        AttachDocumentPolicyRequest,
        AttachDocumentPolicyRequestTypedDict,
        AttachDocumentPolicyResponse,
        AttachDocumentPolicyResponseTypedDict,
        AttachPolicyRequest,
        AttachPolicyRequestTypedDict,
    )
    from .checkaccessrequeststatusop import (
        CheckAccessRequestStatusRequest,
        CheckAccessRequestStatusRequestTypedDict,
        CheckAccessRequestStatusResponseResponse,
        CheckAccessRequestStatusResponseResponseTypedDict,
    )
    from .checkaccessrequeststatusresponse import (
        CheckAccessRequestStatusResponse,
        CheckAccessRequestStatusResponseTypedDict,
    )
    from .createaccessrequestop import (
        CreateAccessRequestCreateAccessRequestRequest,
        CreateAccessRequestCreateAccessRequestRequestTypedDict,
        CreateAccessRequestRequest,
        CreateAccessRequestRequestTypedDict,
        CreateAccessRequestResponseResponse,
        CreateAccessRequestResponseResponseTypedDict,
    )
    from .createaccessrequestresponse import (
        CreateAccessRequestResponse,
        CreateAccessRequestResponseTypedDict,
    )
    from .createapikeyop import (
        CreateAPIKeyResponseResponse,
        CreateAPIKeyResponseResponseTypedDict,
    )
    from .createapikeyrequest import CreateAPIKeyRequest, CreateAPIKeyRequestTypedDict
    from .createapikeyresponse import (
        CreateAPIKeyResponse,
        CreateAPIKeyResponseTypedDict,
    )
    from .createdocumentop import (
        CreateDocumentResponseResponse,
        CreateDocumentResponseResponseTypedDict,
    )
    from .createdocumentrequest import (
        CreateDocumentRequest,
        CreateDocumentRequestPayload,
        CreateDocumentRequestPayloadTypedDict,
        CreateDocumentRequestTypedDict,
    )
    from .createdocumentresponse import (
        CreateDocumentResponse,
        CreateDocumentResponseTypedDict,
    )
    from .createdocumentversionop import (
        CreateDocumentVersionRequest,
        CreateDocumentVersionRequestTypedDict,
        CreateDocumentVersionResponse,
        CreateDocumentVersionResponseTypedDict,
    )
    from .createorganizationinviteop import (
        CreateOrganizationInviteCreateOrganizationInviteRequest,
        CreateOrganizationInviteCreateOrganizationInviteRequestTypedDict,
        CreateOrganizationInviteRequest,
        CreateOrganizationInviteRequestTypedDict,
        CreateOrganizationInviteResponseResponse,
        CreateOrganizationInviteResponseResponseTypedDict,
    )
    from .createorganizationinviteresponse import (
        CreateOrganizationInviteResponse,
        CreateOrganizationInviteResponseTypedDict,
    )
    from .createsharelinkop import (
        CreateShareLinkCreateShareLinkRequest,
        CreateShareLinkCreateShareLinkRequestTypedDict,
        CreateShareLinkRequest,
        CreateShareLinkRequestTypedDict,
        CreateShareLinkResponseResponse,
        CreateShareLinkResponseResponseTypedDict,
    )
    from .createsharelinkresponse import (
        CreateShareLinkResponse,
        CreateShareLinkResponseTypedDict,
    )
    from .createversionrequest import (
        CreateVersionRequest,
        CreateVersionRequestPayload,
        CreateVersionRequestPayloadTypedDict,
        CreateVersionRequestTypedDict,
    )
    from .dailyusage import DailyUsage, DailyUsageTypedDict
    from .deleteapikeyquotaop import (
        DeleteAPIKeyQuotaRequest,
        DeleteAPIKeyQuotaRequestTypedDict,
        DeleteAPIKeyQuotaResponseResponse,
        DeleteAPIKeyQuotaResponseResponseTypedDict,
    )
    from .deleteapikeyquotaresponse import (
        DeleteAPIKeyQuotaResponse,
        DeleteAPIKeyQuotaResponseTypedDict,
    )
    from .denyaccessrequestop import (
        DenyAccessRequestDenyAccessRequestRequest,
        DenyAccessRequestDenyAccessRequestRequestTypedDict,
        DenyAccessRequestRequest,
        DenyAccessRequestRequestTypedDict,
        DenyAccessRequestResponseResponse,
        DenyAccessRequestResponseResponseTypedDict,
    )
    from .denyaccessrequestresponse import (
        DenyAccessRequestResponse,
        DenyAccessRequestResponseTypedDict,
    )
    from .detachdocumentpolicyop import (
        DetachDocumentPolicyRequest,
        DetachDocumentPolicyRequestTypedDict,
        DetachDocumentPolicyResponse,
        DetachDocumentPolicyResponseTypedDict,
    )
    from .document import Document, DocumentTypedDict
    from .documentownership import DocumentOwnership
    from .documentpermissionset import (
        DocumentPermissionSet,
        DocumentPermissionSetTypedDict,
    )
    from .documentpolicy import DocumentPolicy, DocumentPolicyTypedDict
    from .documentrole import DocumentRole
    from .documenttrashstate import DocumentTrashState
    from .duplicatedocument import DuplicateDocument, DuplicateDocumentTypedDict
    from .empty import Empty, EmptyTypedDict
    from .errordetail import ErrorDetail, ErrorDetailTypedDict, Reason
    from .errorresponse import Code
    from .exportdocumentop import (
        ExportDocumentRequest,
        ExportDocumentRequestTypedDict,
        ExportDocumentResponseResponse,
        ExportDocumentResponseResponseTypedDict,
    )
    from .exportdocumentresponse import (
        ExportDocumentResponse,
        ExportDocumentResponseTypedDict,
    )
    from .generalaccesslevel import GeneralAccessLevel
    from .generatedocumententrypageop import (
        GenerateDocumentEntryPageRequest,
        GenerateDocumentEntryPageRequestTypedDict,
        GenerateDocumentEntryPageResponse,
        GenerateDocumentEntryPageResponseTypedDict,
    )
    from .generateentrypageresponse import (
        GenerateEntryPageResponse,
        GenerateEntryPageResponseTypedDict,
    )
    from .getdocumentop import (
        GetDocumentRequest,
        GetDocumentRequestTypedDict,
        GetDocumentResponseResponse,
        GetDocumentResponseResponseTypedDict,
    )
    from .getdocumentquotaop import (
        GetDocumentQuotaResponseResponse,
        GetDocumentQuotaResponseResponseTypedDict,
    )
    from .getdocumentquotaresponse import (
        GetDocumentQuotaResponse,
        GetDocumentQuotaResponseTypedDict,
    )
    from .getdocumentresponse import GetDocumentResponse, GetDocumentResponseTypedDict
    from .getdocumenttimelineop import (
        GetDocumentTimelineRequest,
        GetDocumentTimelineRequestTypedDict,
        GetDocumentTimelineResponse,
        GetDocumentTimelineResponseTypedDict,
    )
    from .getgeneralaccessop import (
        GetGeneralAccessRequest,
        GetGeneralAccessRequestTypedDict,
        GetGeneralAccessResponseResponse,
        GetGeneralAccessResponseResponseTypedDict,
    )
    from .getgeneralaccessresponse import (
        GetGeneralAccessResponse,
        GetGeneralAccessResponseTypedDict,
    )
    from .getmeop import GetMeResponseResponse, GetMeResponseResponseTypedDict
    from .getmeresponse import GetMeResponse, GetMeResponseTypedDict
    from .getorganizationop import (
        GetOrganizationRequest,
        GetOrganizationRequestTypedDict,
        GetOrganizationResponseResponse,
        GetOrganizationResponseResponseTypedDict,
    )
    from .getorganizationquotaop import (
        GetOrganizationQuotaRequest,
        GetOrganizationQuotaRequestTypedDict,
        GetOrganizationQuotaResponseResponse,
        GetOrganizationQuotaResponseResponseTypedDict,
    )
    from .getorganizationquotaresponse import (
        GetOrganizationQuotaResponse,
        GetOrganizationQuotaResponseTypedDict,
    )
    from .getorganizationresponse import (
        GetOrganizationResponse,
        GetOrganizationResponseTypedDict,
    )
    from .gettimelineresponse import GetTimelineResponse, GetTimelineResponseTypedDict
    from .getusagehistoryop import (
        GetUsageHistoryRequest,
        GetUsageHistoryRequestTypedDict,
        GetUsageHistoryResponseResponse,
        GetUsageHistoryResponseResponseTypedDict,
    )
    from .getusagehistoryresponse import (
        GetUsageHistoryResponse,
        GetUsageHistoryResponseTypedDict,
    )
    from .getuserpreferencesop import (
        GetUserPreferencesResponseResponse,
        GetUserPreferencesResponseResponseTypedDict,
    )
    from .getuserpreferencesresponse import (
        GetUserPreferencesResponse,
        GetUserPreferencesResponseTypedDict,
    )
    from .getversionop import (
        GetVersionRequest,
        GetVersionRequestTypedDict,
        GetVersionResponse,
        GetVersionResponseTypedDict,
    )
    from .grantdocumentaccessop import (
        GrantDocumentAccessGrantDocumentAccessRequest,
        GrantDocumentAccessGrantDocumentAccessRequestTypedDict,
        GrantDocumentAccessRequest,
        GrantDocumentAccessRequestTypedDict,
        GrantDocumentAccessResponseResponse,
        GrantDocumentAccessResponseResponseTypedDict,
    )
    from .grantdocumentaccessresponse import (
        GrantDocumentAccessResponse,
        GrantDocumentAccessResponseTypedDict,
    )
    from .inspectaccessresponse import (
        InspectAccessResponse,
        InspectAccessResponseTypedDict,
    )
    from .inspectdocumentaccessop import (
        InspectDocumentAccessRequest,
        InspectDocumentAccessRequestTypedDict,
        InspectDocumentAccessResponse,
        InspectDocumentAccessResponseTypedDict,
    )
    from .listaccessrequestsop import (
        ListAccessRequestsRequest,
        ListAccessRequestsRequestTypedDict,
        ListAccessRequestsResponseResponse,
        ListAccessRequestsResponseResponseTypedDict,
    )
    from .listaccessrequestsresponse import (
        ListAccessRequestsResponse,
        ListAccessRequestsResponseTypedDict,
    )
    from .listapikeyquotasop import (
        ListAPIKeyQuotasRequest,
        ListAPIKeyQuotasRequestTypedDict,
        ListAPIKeyQuotasResponseResponse,
        ListAPIKeyQuotasResponseResponseTypedDict,
    )
    from .listapikeyquotasresponse import (
        ListAPIKeyQuotasResponse,
        ListAPIKeyQuotasResponseTypedDict,
    )
    from .listapikeysop import (
        ListAPIKeysRequest,
        ListAPIKeysRequestTypedDict,
        ListAPIKeysResponseResponse,
        ListAPIKeysResponseResponseTypedDict,
    )
    from .listapikeysresponse import ListAPIKeysResponse, ListAPIKeysResponseTypedDict
    from .listdocumentaccessop import (
        ListDocumentAccessRequest,
        ListDocumentAccessRequestTypedDict,
        ListDocumentAccessResponseResponse,
        ListDocumentAccessResponseResponseTypedDict,
    )
    from .listdocumentaccessresponse import (
        ListDocumentAccessResponse,
        ListDocumentAccessResponseTypedDict,
    )
    from .listdocumentduplicatesop import (
        ListDocumentDuplicatesRequest,
        ListDocumentDuplicatesRequestTypedDict,
        ListDocumentDuplicatesResponseResponse,
        ListDocumentDuplicatesResponseResponseTypedDict,
    )
    from .listdocumentduplicatesresponse import (
        ListDocumentDuplicatesResponse,
        ListDocumentDuplicatesResponseTypedDict,
    )
    from .listdocumentpoliciesop import (
        ListDocumentPoliciesRequest,
        ListDocumentPoliciesRequestTypedDict,
        ListDocumentPoliciesResponseResponse,
        ListDocumentPoliciesResponseResponseTypedDict,
    )
    from .listdocumentpoliciesresponse import (
        ListDocumentPoliciesResponse,
        ListDocumentPoliciesResponseTypedDict,
    )
    from .listdocumentsop import (
        ListDocumentsRequest,
        ListDocumentsRequestTypedDict,
        ListDocumentsResponseResponse,
        ListDocumentsResponseResponseTypedDict,
    )
    from .listdocumentsresponse import (
        ListDocumentsResponse,
        ListDocumentsResponseTypedDict,
    )
    from .listdocumentversionsop import (
        ListDocumentVersionsRequest,
        ListDocumentVersionsRequestTypedDict,
        ListDocumentVersionsResponse,
        ListDocumentVersionsResponseTypedDict,
    )
    from .listorganizationinvitesop import (
        ListOrganizationInvitesRequest,
        ListOrganizationInvitesRequestTypedDict,
        ListOrganizationInvitesResponseResponse,
        ListOrganizationInvitesResponseResponseTypedDict,
    )
    from .listorganizationinvitesresponse import (
        ListOrganizationInvitesResponse,
        ListOrganizationInvitesResponseTypedDict,
    )
    from .listorganizationmembersop import (
        ListOrganizationMembersRequest,
        ListOrganizationMembersRequestTypedDict,
        ListOrganizationMembersResponseResponse,
        ListOrganizationMembersResponseResponseTypedDict,
    )
    from .listorganizationmembersresponse import (
        ListOrganizationMembersResponse,
        ListOrganizationMembersResponseTypedDict,
    )
    from .listorganizationsop import (
        ListOrganizationsRequest,
        ListOrganizationsRequestTypedDict,
        ListOrganizationsResponseResponse,
        ListOrganizationsResponseResponseTypedDict,
    )
    from .listorganizationsresponse import (
        ListOrganizationsResponse,
        ListOrganizationsResponseTypedDict,
    )
    from .listversionsresponse import (
        ListVersionsResponse,
        ListVersionsResponseTypedDict,
    )
    from .organization import Organization, OrganizationTypedDict
    from .organizationinvite import OrganizationInvite, OrganizationInviteTypedDict
    from .organizationinvitestatus import OrganizationInviteStatus
    from .organizationmember import OrganizationMember, OrganizationMemberTypedDict
    from .organizationquota import OrganizationQuota, OrganizationQuotaTypedDict
    from .organizationrole import OrganizationRole
    from .pagination import Pagination, PaginationTypedDict
    from .policy import Policy, PolicyTypedDict
    from .processdocumentop import (
        ProcessDocumentProcessDocumentRequest,
        ProcessDocumentProcessDocumentRequestTypedDict,
        ProcessDocumentRequest,
        ProcessDocumentRequestTypedDict,
        ProcessDocumentResponseResponse,
        ProcessDocumentResponseResponseTypedDict,
    )
    from .processdocumentresponse import (
        ProcessDocumentResponse,
        ProcessDocumentResponseTypedDict,
    )
    from .processingoutcome import ProcessingOutcome
    from .processingstatus import ProcessingStatus
    from .quotatier import QuotaTier
    from .recipient import Recipient, RecipientTypedDict
    from .recipientgrant import RecipientGrant, RecipientGrantTypedDict
    from .recipienttype import RecipientType
    from .removeorganizationmemberop import (
        RemoveOrganizationMemberRequest,
        RemoveOrganizationMemberRequestTypedDict,
        RemoveOrganizationMemberResponseResponse,
        RemoveOrganizationMemberResponseResponseTypedDict,
    )
    from .removeorganizationmemberresponse import (
        RemoveOrganizationMemberResponse,
        RemoveOrganizationMemberResponseTypedDict,
    )
    from .resendorganizationinviteop import (
        ResendOrganizationInviteRequest,
        ResendOrganizationInviteRequestTypedDict,
        ResendOrganizationInviteResendOrganizationInviteRequest,
        ResendOrganizationInviteResendOrganizationInviteRequestTypedDict,
        ResendOrganizationInviteResponseResponse,
        ResendOrganizationInviteResponseResponseTypedDict,
    )
    from .resendorganizationinviteresponse import (
        ResendOrganizationInviteResponse,
        ResendOrganizationInviteResponseTypedDict,
    )
    from .revokeapikeyop import (
        RevokeAPIKeyRequest,
        RevokeAPIKeyRequestTypedDict,
        RevokeAPIKeyResponseResponse,
        RevokeAPIKeyResponseResponseTypedDict,
        RevokeAPIKeyRevokeAPIKeyRequest,
        RevokeAPIKeyRevokeAPIKeyRequestTypedDict,
    )
    from .revokeapikeyresponse import (
        RevokeAPIKeyResponse,
        RevokeAPIKeyResponseTypedDict,
    )
    from .revokedocumentaccessop import (
        RevokeDocumentAccessRequest,
        RevokeDocumentAccessRequestTypedDict,
        RevokeDocumentAccessResponseResponse,
        RevokeDocumentAccessResponseResponseTypedDict,
    )
    from .revokedocumentaccessresponse import (
        RevokeDocumentAccessResponse,
        RevokeDocumentAccessResponseTypedDict,
    )
    from .revokeorganizationinviteop import (
        RevokeOrganizationInviteRequest,
        RevokeOrganizationInviteRequestTypedDict,
        RevokeOrganizationInviteResponseResponse,
        RevokeOrganizationInviteResponseResponseTypedDict,
        RevokeOrganizationInviteRevokeOrganizationInviteRequest,
        RevokeOrganizationInviteRevokeOrganizationInviteRequestTypedDict,
    )
    from .revokeorganizationinviteresponse import (
        RevokeOrganizationInviteResponse,
        RevokeOrganizationInviteResponseTypedDict,
    )
    from .security import Security, SecurityTypedDict
    from .setapikeyquotaop import (
        SetAPIKeyQuotaRequest,
        SetAPIKeyQuotaRequestTypedDict,
        SetAPIKeyQuotaResponseResponse,
        SetAPIKeyQuotaResponseResponseTypedDict,
        SetAPIKeyQuotaSetAPIKeyQuotaRequest,
        SetAPIKeyQuotaSetAPIKeyQuotaRequestTypedDict,
    )
    from .setapikeyquotaresponse import (
        SetAPIKeyQuotaResponse,
        SetAPIKeyQuotaResponseTypedDict,
    )
    from .setgeneralaccessop import (
        SetGeneralAccessRequest,
        SetGeneralAccessRequestTypedDict,
        SetGeneralAccessResponseResponse,
        SetGeneralAccessResponseResponseTypedDict,
        SetGeneralAccessSetGeneralAccessRequest,
        SetGeneralAccessSetGeneralAccessRequestTypedDict,
    )
    from .setgeneralaccessresponse import (
        SetGeneralAccessResponse,
        SetGeneralAccessResponseTypedDict,
    )
    from .sharelink import ShareLink, ShareLinkTypedDict
    from .subject import Subject, SubjectTypedDict
    from .subjecttype import SubjectType
    from .timelineevent import TimelineEvent, TimelineEventTypedDict
    from .timelineeventtype import TimelineEventType
    from .transferdocumentownershipop import (
        TransferDocumentOwnershipRequest,
        TransferDocumentOwnershipRequestTypedDict,
        TransferDocumentOwnershipResponseResponse,
        TransferDocumentOwnershipResponseResponseTypedDict,
        TransferDocumentOwnershipTransferDocumentOwnershipRequest,
        TransferDocumentOwnershipTransferDocumentOwnershipRequestTypedDict,
    )
    from .transferdocumentownershipresponse import (
        TransferDocumentOwnershipResponse,
        TransferDocumentOwnershipResponseTypedDict,
    )
    from .trashdocumentop import (
        TrashDocumentRequest,
        TrashDocumentRequestTypedDict,
        TrashDocumentResponseResponse,
        TrashDocumentResponseResponseTypedDict,
        TrashDocumentTrashDocumentRequest,
        TrashDocumentTrashDocumentRequestTypedDict,
    )
    from .trashdocumentresponse import (
        TrashDocumentResponse,
        TrashDocumentResponseTypedDict,
    )
    from .untrashdocumentop import (
        UntrashDocumentRequest,
        UntrashDocumentRequestTypedDict,
        UntrashDocumentResponseResponse,
        UntrashDocumentResponseResponseTypedDict,
        UntrashDocumentUntrashDocumentRequest,
        UntrashDocumentUntrashDocumentRequestTypedDict,
    )
    from .untrashdocumentresponse import (
        UntrashDocumentResponse,
        UntrashDocumentResponseTypedDict,
    )
    from .updatedocumentaccessop import (
        UpdateDocumentAccessRequest,
        UpdateDocumentAccessRequestTypedDict,
        UpdateDocumentAccessResponseResponse,
        UpdateDocumentAccessResponseResponseTypedDict,
        UpdateDocumentAccessUpdateDocumentAccessRequest,
        UpdateDocumentAccessUpdateDocumentAccessRequestTypedDict,
    )
    from .updatedocumentaccessresponse import (
        UpdateDocumentAccessResponse,
        UpdateDocumentAccessResponseTypedDict,
    )
    from .updatedocumentop import (
        UpdateDocumentRequest,
        UpdateDocumentRequestTypedDict,
        UpdateDocumentResponseResponse,
        UpdateDocumentResponseResponseTypedDict,
        UpdateDocumentUpdateDocumentRequest,
        UpdateDocumentUpdateDocumentRequestTypedDict,
    )
    from .updatedocumentresponse import (
        UpdateDocumentResponse,
        UpdateDocumentResponseTypedDict,
    )
    from .updateorganizationmemberop import (
        UpdateOrganizationMemberRequest,
        UpdateOrganizationMemberRequestTypedDict,
        UpdateOrganizationMemberResponseResponse,
        UpdateOrganizationMemberResponseResponseTypedDict,
        UpdateOrganizationMemberUpdateOrganizationMemberRequest,
        UpdateOrganizationMemberUpdateOrganizationMemberRequestTypedDict,
    )
    from .updateorganizationmemberresponse import (
        UpdateOrganizationMemberResponse,
        UpdateOrganizationMemberResponseTypedDict,
    )
    from .updateorganizationop import (
        UpdateOrganizationRequest,
        UpdateOrganizationRequestTypedDict,
        UpdateOrganizationResponseResponse,
        UpdateOrganizationResponseResponseTypedDict,
        UpdateOrganizationUpdateOrganizationRequest,
        UpdateOrganizationUpdateOrganizationRequestTypedDict,
    )
    from .updateorganizationresponse import (
        UpdateOrganizationResponse,
        UpdateOrganizationResponseTypedDict,
    )
    from .updateversionop import (
        UpdateVersionRequest,
        UpdateVersionRequestTypedDict,
        UpdateVersionResponse,
        UpdateVersionResponseTypedDict,
        UpdateVersionUpdateVersionRequest,
        UpdateVersionUpdateVersionRequestTypedDict,
    )
    from .user import User, UserTypedDict
    from .value import Value, ValueTypedDict
    from .version import Version, VersionTypedDict
    from .versionref import VersionRef, VersionRefTypedDict

__all__ = [
    "APIKey",
    "APIKeyQuota",
    "APIKeyQuotaTypedDict",
    "APIKeyTypedDict",
    "AcceptOrganizationInviteAcceptOrganizationInviteRequest",
    "AcceptOrganizationInviteAcceptOrganizationInviteRequestTypedDict",
    "AcceptOrganizationInviteRequest",
    "AcceptOrganizationInviteRequestTypedDict",
    "AcceptOrganizationInviteResponse",
    "AcceptOrganizationInviteResponseResponse",
    "AcceptOrganizationInviteResponseResponseTypedDict",
    "AcceptOrganizationInviteResponseTypedDict",
    "AccessGrantResult",
    "AccessGrantResultTypedDict",
    "AccessLevel",
    "AccessRequest",
    "AccessRequestPermission",
    "AccessRequestStatus",
    "AccessRequestTypedDict",
    "AddOrganizationMemberAddOrganizationMemberRequest",
    "AddOrganizationMemberAddOrganizationMemberRequestTypedDict",
    "AddOrganizationMemberRequest",
    "AddOrganizationMemberRequestTypedDict",
    "AddOrganizationMemberResponse",
    "AddOrganizationMemberResponseResponse",
    "AddOrganizationMemberResponseResponseTypedDict",
    "AddOrganizationMemberResponseTypedDict",
    "ApproveAccessRequestApproveAccessRequestRequest",
    "ApproveAccessRequestApproveAccessRequestRequestTypedDict",
    "ApproveAccessRequestRequest",
    "ApproveAccessRequestRequestTypedDict",
    "ApproveAccessRequestResponse",
    "ApproveAccessRequestResponseResponse",
    "ApproveAccessRequestResponseResponseTypedDict",
    "ApproveAccessRequestResponseTypedDict",
    "AttachDocumentPolicyRequest",
    "AttachDocumentPolicyRequestTypedDict",
    "AttachDocumentPolicyResponse",
    "AttachDocumentPolicyResponseTypedDict",
    "AttachPolicyRequest",
    "AttachPolicyRequestTypedDict",
    "CheckAccessRequestStatusRequest",
    "CheckAccessRequestStatusRequestTypedDict",
    "CheckAccessRequestStatusResponse",
    "CheckAccessRequestStatusResponseResponse",
    "CheckAccessRequestStatusResponseResponseTypedDict",
    "CheckAccessRequestStatusResponseTypedDict",
    "Code",
    "CreateAPIKeyRequest",
    "CreateAPIKeyRequestTypedDict",
    "CreateAPIKeyResponse",
    "CreateAPIKeyResponseResponse",
    "CreateAPIKeyResponseResponseTypedDict",
    "CreateAPIKeyResponseTypedDict",
    "CreateAccessRequestCreateAccessRequestRequest",
    "CreateAccessRequestCreateAccessRequestRequestTypedDict",
    "CreateAccessRequestRequest",
    "CreateAccessRequestRequestTypedDict",
    "CreateAccessRequestResponse",
    "CreateAccessRequestResponseResponse",
    "CreateAccessRequestResponseResponseTypedDict",
    "CreateAccessRequestResponseTypedDict",
    "CreateDocumentRequest",
    "CreateDocumentRequestPayload",
    "CreateDocumentRequestPayloadTypedDict",
    "CreateDocumentRequestTypedDict",
    "CreateDocumentResponse",
    "CreateDocumentResponseResponse",
    "CreateDocumentResponseResponseTypedDict",
    "CreateDocumentResponseTypedDict",
    "CreateDocumentVersionRequest",
    "CreateDocumentVersionRequestTypedDict",
    "CreateDocumentVersionResponse",
    "CreateDocumentVersionResponseTypedDict",
    "CreateOrganizationInviteCreateOrganizationInviteRequest",
    "CreateOrganizationInviteCreateOrganizationInviteRequestTypedDict",
    "CreateOrganizationInviteRequest",
    "CreateOrganizationInviteRequestTypedDict",
    "CreateOrganizationInviteResponse",
    "CreateOrganizationInviteResponseResponse",
    "CreateOrganizationInviteResponseResponseTypedDict",
    "CreateOrganizationInviteResponseTypedDict",
    "CreateShareLinkCreateShareLinkRequest",
    "CreateShareLinkCreateShareLinkRequestTypedDict",
    "CreateShareLinkRequest",
    "CreateShareLinkRequestTypedDict",
    "CreateShareLinkResponse",
    "CreateShareLinkResponseResponse",
    "CreateShareLinkResponseResponseTypedDict",
    "CreateShareLinkResponseTypedDict",
    "CreateVersionRequest",
    "CreateVersionRequestPayload",
    "CreateVersionRequestPayloadTypedDict",
    "CreateVersionRequestTypedDict",
    "DailyUsage",
    "DailyUsageTypedDict",
    "DeleteAPIKeyQuotaRequest",
    "DeleteAPIKeyQuotaRequestTypedDict",
    "DeleteAPIKeyQuotaResponse",
    "DeleteAPIKeyQuotaResponseResponse",
    "DeleteAPIKeyQuotaResponseResponseTypedDict",
    "DeleteAPIKeyQuotaResponseTypedDict",
    "DenyAccessRequestDenyAccessRequestRequest",
    "DenyAccessRequestDenyAccessRequestRequestTypedDict",
    "DenyAccessRequestRequest",
    "DenyAccessRequestRequestTypedDict",
    "DenyAccessRequestResponse",
    "DenyAccessRequestResponseResponse",
    "DenyAccessRequestResponseResponseTypedDict",
    "DenyAccessRequestResponseTypedDict",
    "DetachDocumentPolicyRequest",
    "DetachDocumentPolicyRequestTypedDict",
    "DetachDocumentPolicyResponse",
    "DetachDocumentPolicyResponseTypedDict",
    "Document",
    "DocumentOwnership",
    "DocumentPermissionSet",
    "DocumentPermissionSetTypedDict",
    "DocumentPolicy",
    "DocumentPolicyTypedDict",
    "DocumentRole",
    "DocumentTrashState",
    "DocumentTypedDict",
    "DuplicateDocument",
    "DuplicateDocumentTypedDict",
    "Empty",
    "EmptyTypedDict",
    "ErrorDetail",
    "ErrorDetailTypedDict",
    "ExportDocumentRequest",
    "ExportDocumentRequestTypedDict",
    "ExportDocumentResponse",
    "ExportDocumentResponseResponse",
    "ExportDocumentResponseResponseTypedDict",
    "ExportDocumentResponseTypedDict",
    "GeneralAccessLevel",
    "GenerateDocumentEntryPageRequest",
    "GenerateDocumentEntryPageRequestTypedDict",
    "GenerateDocumentEntryPageResponse",
    "GenerateDocumentEntryPageResponseTypedDict",
    "GenerateEntryPageResponse",
    "GenerateEntryPageResponseTypedDict",
    "GetDocumentQuotaResponse",
    "GetDocumentQuotaResponseResponse",
    "GetDocumentQuotaResponseResponseTypedDict",
    "GetDocumentQuotaResponseTypedDict",
    "GetDocumentRequest",
    "GetDocumentRequestTypedDict",
    "GetDocumentResponse",
    "GetDocumentResponseResponse",
    "GetDocumentResponseResponseTypedDict",
    "GetDocumentResponseTypedDict",
    "GetDocumentTimelineRequest",
    "GetDocumentTimelineRequestTypedDict",
    "GetDocumentTimelineResponse",
    "GetDocumentTimelineResponseTypedDict",
    "GetGeneralAccessRequest",
    "GetGeneralAccessRequestTypedDict",
    "GetGeneralAccessResponse",
    "GetGeneralAccessResponseResponse",
    "GetGeneralAccessResponseResponseTypedDict",
    "GetGeneralAccessResponseTypedDict",
    "GetMeResponse",
    "GetMeResponseResponse",
    "GetMeResponseResponseTypedDict",
    "GetMeResponseTypedDict",
    "GetOrganizationQuotaRequest",
    "GetOrganizationQuotaRequestTypedDict",
    "GetOrganizationQuotaResponse",
    "GetOrganizationQuotaResponseResponse",
    "GetOrganizationQuotaResponseResponseTypedDict",
    "GetOrganizationQuotaResponseTypedDict",
    "GetOrganizationRequest",
    "GetOrganizationRequestTypedDict",
    "GetOrganizationResponse",
    "GetOrganizationResponseResponse",
    "GetOrganizationResponseResponseTypedDict",
    "GetOrganizationResponseTypedDict",
    "GetTimelineResponse",
    "GetTimelineResponseTypedDict",
    "GetUsageHistoryRequest",
    "GetUsageHistoryRequestTypedDict",
    "GetUsageHistoryResponse",
    "GetUsageHistoryResponseResponse",
    "GetUsageHistoryResponseResponseTypedDict",
    "GetUsageHistoryResponseTypedDict",
    "GetUserPreferencesResponse",
    "GetUserPreferencesResponseResponse",
    "GetUserPreferencesResponseResponseTypedDict",
    "GetUserPreferencesResponseTypedDict",
    "GetVersionRequest",
    "GetVersionRequestTypedDict",
    "GetVersionResponse",
    "GetVersionResponseTypedDict",
    "GrantDocumentAccessGrantDocumentAccessRequest",
    "GrantDocumentAccessGrantDocumentAccessRequestTypedDict",
    "GrantDocumentAccessRequest",
    "GrantDocumentAccessRequestTypedDict",
    "GrantDocumentAccessResponse",
    "GrantDocumentAccessResponseResponse",
    "GrantDocumentAccessResponseResponseTypedDict",
    "GrantDocumentAccessResponseTypedDict",
    "InspectAccessResponse",
    "InspectAccessResponseTypedDict",
    "InspectDocumentAccessRequest",
    "InspectDocumentAccessRequestTypedDict",
    "InspectDocumentAccessResponse",
    "InspectDocumentAccessResponseTypedDict",
    "ListAPIKeyQuotasRequest",
    "ListAPIKeyQuotasRequestTypedDict",
    "ListAPIKeyQuotasResponse",
    "ListAPIKeyQuotasResponseResponse",
    "ListAPIKeyQuotasResponseResponseTypedDict",
    "ListAPIKeyQuotasResponseTypedDict",
    "ListAPIKeysRequest",
    "ListAPIKeysRequestTypedDict",
    "ListAPIKeysResponse",
    "ListAPIKeysResponseResponse",
    "ListAPIKeysResponseResponseTypedDict",
    "ListAPIKeysResponseTypedDict",
    "ListAccessRequestsRequest",
    "ListAccessRequestsRequestTypedDict",
    "ListAccessRequestsResponse",
    "ListAccessRequestsResponseResponse",
    "ListAccessRequestsResponseResponseTypedDict",
    "ListAccessRequestsResponseTypedDict",
    "ListDocumentAccessRequest",
    "ListDocumentAccessRequestTypedDict",
    "ListDocumentAccessResponse",
    "ListDocumentAccessResponseResponse",
    "ListDocumentAccessResponseResponseTypedDict",
    "ListDocumentAccessResponseTypedDict",
    "ListDocumentDuplicatesRequest",
    "ListDocumentDuplicatesRequestTypedDict",
    "ListDocumentDuplicatesResponse",
    "ListDocumentDuplicatesResponseResponse",
    "ListDocumentDuplicatesResponseResponseTypedDict",
    "ListDocumentDuplicatesResponseTypedDict",
    "ListDocumentPoliciesRequest",
    "ListDocumentPoliciesRequestTypedDict",
    "ListDocumentPoliciesResponse",
    "ListDocumentPoliciesResponseResponse",
    "ListDocumentPoliciesResponseResponseTypedDict",
    "ListDocumentPoliciesResponseTypedDict",
    "ListDocumentVersionsRequest",
    "ListDocumentVersionsRequestTypedDict",
    "ListDocumentVersionsResponse",
    "ListDocumentVersionsResponseTypedDict",
    "ListDocumentsRequest",
    "ListDocumentsRequestTypedDict",
    "ListDocumentsResponse",
    "ListDocumentsResponseResponse",
    "ListDocumentsResponseResponseTypedDict",
    "ListDocumentsResponseTypedDict",
    "ListOrganizationInvitesRequest",
    "ListOrganizationInvitesRequestTypedDict",
    "ListOrganizationInvitesResponse",
    "ListOrganizationInvitesResponseResponse",
    "ListOrganizationInvitesResponseResponseTypedDict",
    "ListOrganizationInvitesResponseTypedDict",
    "ListOrganizationMembersRequest",
    "ListOrganizationMembersRequestTypedDict",
    "ListOrganizationMembersResponse",
    "ListOrganizationMembersResponseResponse",
    "ListOrganizationMembersResponseResponseTypedDict",
    "ListOrganizationMembersResponseTypedDict",
    "ListOrganizationsRequest",
    "ListOrganizationsRequestTypedDict",
    "ListOrganizationsResponse",
    "ListOrganizationsResponseResponse",
    "ListOrganizationsResponseResponseTypedDict",
    "ListOrganizationsResponseTypedDict",
    "ListVersionsResponse",
    "ListVersionsResponseTypedDict",
    "Organization",
    "OrganizationInvite",
    "OrganizationInviteStatus",
    "OrganizationInviteTypedDict",
    "OrganizationMember",
    "OrganizationMemberTypedDict",
    "OrganizationQuota",
    "OrganizationQuotaTypedDict",
    "OrganizationRole",
    "OrganizationTypedDict",
    "Pagination",
    "PaginationTypedDict",
    "Policy",
    "PolicyTypedDict",
    "ProcessDocumentProcessDocumentRequest",
    "ProcessDocumentProcessDocumentRequestTypedDict",
    "ProcessDocumentRequest",
    "ProcessDocumentRequestTypedDict",
    "ProcessDocumentResponse",
    "ProcessDocumentResponseResponse",
    "ProcessDocumentResponseResponseTypedDict",
    "ProcessDocumentResponseTypedDict",
    "ProcessingOutcome",
    "ProcessingStatus",
    "QuotaTier",
    "Reason",
    "Recipient",
    "RecipientGrant",
    "RecipientGrantTypedDict",
    "RecipientType",
    "RecipientTypedDict",
    "RemoveOrganizationMemberRequest",
    "RemoveOrganizationMemberRequestTypedDict",
    "RemoveOrganizationMemberResponse",
    "RemoveOrganizationMemberResponseResponse",
    "RemoveOrganizationMemberResponseResponseTypedDict",
    "RemoveOrganizationMemberResponseTypedDict",
    "ResendOrganizationInviteRequest",
    "ResendOrganizationInviteRequestTypedDict",
    "ResendOrganizationInviteResendOrganizationInviteRequest",
    "ResendOrganizationInviteResendOrganizationInviteRequestTypedDict",
    "ResendOrganizationInviteResponse",
    "ResendOrganizationInviteResponseResponse",
    "ResendOrganizationInviteResponseResponseTypedDict",
    "ResendOrganizationInviteResponseTypedDict",
    "RevokeAPIKeyRequest",
    "RevokeAPIKeyRequestTypedDict",
    "RevokeAPIKeyResponse",
    "RevokeAPIKeyResponseResponse",
    "RevokeAPIKeyResponseResponseTypedDict",
    "RevokeAPIKeyResponseTypedDict",
    "RevokeAPIKeyRevokeAPIKeyRequest",
    "RevokeAPIKeyRevokeAPIKeyRequestTypedDict",
    "RevokeDocumentAccessRequest",
    "RevokeDocumentAccessRequestTypedDict",
    "RevokeDocumentAccessResponse",
    "RevokeDocumentAccessResponseResponse",
    "RevokeDocumentAccessResponseResponseTypedDict",
    "RevokeDocumentAccessResponseTypedDict",
    "RevokeOrganizationInviteRequest",
    "RevokeOrganizationInviteRequestTypedDict",
    "RevokeOrganizationInviteResponse",
    "RevokeOrganizationInviteResponseResponse",
    "RevokeOrganizationInviteResponseResponseTypedDict",
    "RevokeOrganizationInviteResponseTypedDict",
    "RevokeOrganizationInviteRevokeOrganizationInviteRequest",
    "RevokeOrganizationInviteRevokeOrganizationInviteRequestTypedDict",
    "Security",
    "SecurityTypedDict",
    "SetAPIKeyQuotaRequest",
    "SetAPIKeyQuotaRequestTypedDict",
    "SetAPIKeyQuotaResponse",
    "SetAPIKeyQuotaResponseResponse",
    "SetAPIKeyQuotaResponseResponseTypedDict",
    "SetAPIKeyQuotaResponseTypedDict",
    "SetAPIKeyQuotaSetAPIKeyQuotaRequest",
    "SetAPIKeyQuotaSetAPIKeyQuotaRequestTypedDict",
    "SetGeneralAccessRequest",
    "SetGeneralAccessRequestTypedDict",
    "SetGeneralAccessResponse",
    "SetGeneralAccessResponseResponse",
    "SetGeneralAccessResponseResponseTypedDict",
    "SetGeneralAccessResponseTypedDict",
    "SetGeneralAccessSetGeneralAccessRequest",
    "SetGeneralAccessSetGeneralAccessRequestTypedDict",
    "ShareLink",
    "ShareLinkTypedDict",
    "Subject",
    "SubjectType",
    "SubjectTypedDict",
    "TimelineEvent",
    "TimelineEventType",
    "TimelineEventTypedDict",
    "TransferDocumentOwnershipRequest",
    "TransferDocumentOwnershipRequestTypedDict",
    "TransferDocumentOwnershipResponse",
    "TransferDocumentOwnershipResponseResponse",
    "TransferDocumentOwnershipResponseResponseTypedDict",
    "TransferDocumentOwnershipResponseTypedDict",
    "TransferDocumentOwnershipTransferDocumentOwnershipRequest",
    "TransferDocumentOwnershipTransferDocumentOwnershipRequestTypedDict",
    "TrashDocumentRequest",
    "TrashDocumentRequestTypedDict",
    "TrashDocumentResponse",
    "TrashDocumentResponseResponse",
    "TrashDocumentResponseResponseTypedDict",
    "TrashDocumentResponseTypedDict",
    "TrashDocumentTrashDocumentRequest",
    "TrashDocumentTrashDocumentRequestTypedDict",
    "UntrashDocumentRequest",
    "UntrashDocumentRequestTypedDict",
    "UntrashDocumentResponse",
    "UntrashDocumentResponseResponse",
    "UntrashDocumentResponseResponseTypedDict",
    "UntrashDocumentResponseTypedDict",
    "UntrashDocumentUntrashDocumentRequest",
    "UntrashDocumentUntrashDocumentRequestTypedDict",
    "UpdateDocumentAccessRequest",
    "UpdateDocumentAccessRequestTypedDict",
    "UpdateDocumentAccessResponse",
    "UpdateDocumentAccessResponseResponse",
    "UpdateDocumentAccessResponseResponseTypedDict",
    "UpdateDocumentAccessResponseTypedDict",
    "UpdateDocumentAccessUpdateDocumentAccessRequest",
    "UpdateDocumentAccessUpdateDocumentAccessRequestTypedDict",
    "UpdateDocumentRequest",
    "UpdateDocumentRequestTypedDict",
    "UpdateDocumentResponse",
    "UpdateDocumentResponseResponse",
    "UpdateDocumentResponseResponseTypedDict",
    "UpdateDocumentResponseTypedDict",
    "UpdateDocumentUpdateDocumentRequest",
    "UpdateDocumentUpdateDocumentRequestTypedDict",
    "UpdateOrganizationMemberRequest",
    "UpdateOrganizationMemberRequestTypedDict",
    "UpdateOrganizationMemberResponse",
    "UpdateOrganizationMemberResponseResponse",
    "UpdateOrganizationMemberResponseResponseTypedDict",
    "UpdateOrganizationMemberResponseTypedDict",
    "UpdateOrganizationMemberUpdateOrganizationMemberRequest",
    "UpdateOrganizationMemberUpdateOrganizationMemberRequestTypedDict",
    "UpdateOrganizationRequest",
    "UpdateOrganizationRequestTypedDict",
    "UpdateOrganizationResponse",
    "UpdateOrganizationResponseResponse",
    "UpdateOrganizationResponseResponseTypedDict",
    "UpdateOrganizationResponseTypedDict",
    "UpdateOrganizationUpdateOrganizationRequest",
    "UpdateOrganizationUpdateOrganizationRequestTypedDict",
    "UpdateVersionRequest",
    "UpdateVersionRequestTypedDict",
    "UpdateVersionResponse",
    "UpdateVersionResponseTypedDict",
    "UpdateVersionUpdateVersionRequest",
    "UpdateVersionUpdateVersionRequestTypedDict",
    "User",
    "UserTypedDict",
    "Value",
    "ValueTypedDict",
    "Version",
    "VersionRef",
    "VersionRefTypedDict",
    "VersionTypedDict",
]

_dynamic_imports: dict[str, str] = {
    "AcceptOrganizationInviteAcceptOrganizationInviteRequest": ".acceptorganizationinviteop",
    "AcceptOrganizationInviteAcceptOrganizationInviteRequestTypedDict": ".acceptorganizationinviteop",
    "AcceptOrganizationInviteRequest": ".acceptorganizationinviteop",
    "AcceptOrganizationInviteRequestTypedDict": ".acceptorganizationinviteop",
    "AcceptOrganizationInviteResponseResponse": ".acceptorganizationinviteop",
    "AcceptOrganizationInviteResponseResponseTypedDict": ".acceptorganizationinviteop",
    "AcceptOrganizationInviteResponse": ".acceptorganizationinviteresponse",
    "AcceptOrganizationInviteResponseTypedDict": ".acceptorganizationinviteresponse",
    "AccessGrantResult": ".accessgrantresult",
    "AccessGrantResultTypedDict": ".accessgrantresult",
    "AccessLevel": ".accesslevel",
    "AccessRequest": ".accessrequest",
    "AccessRequestTypedDict": ".accessrequest",
    "AccessRequestPermission": ".accessrequestpermission",
    "AccessRequestStatus": ".accessrequeststatus",
    "AddOrganizationMemberAddOrganizationMemberRequest": ".addorganizationmemberop",
    "AddOrganizationMemberAddOrganizationMemberRequestTypedDict": ".addorganizationmemberop",
    "AddOrganizationMemberRequest": ".addorganizationmemberop",
    "AddOrganizationMemberRequestTypedDict": ".addorganizationmemberop",
    "AddOrganizationMemberResponseResponse": ".addorganizationmemberop",
    "AddOrganizationMemberResponseResponseTypedDict": ".addorganizationmemberop",
    "AddOrganizationMemberResponse": ".addorganizationmemberresponse",
    "AddOrganizationMemberResponseTypedDict": ".addorganizationmemberresponse",
    "APIKey": ".apikey",
    "APIKeyTypedDict": ".apikey",
    "APIKeyQuota": ".apikeyquota",
    "APIKeyQuotaTypedDict": ".apikeyquota",
    "ApproveAccessRequestApproveAccessRequestRequest": ".approveaccessrequestop",
    "ApproveAccessRequestApproveAccessRequestRequestTypedDict": ".approveaccessrequestop",
    "ApproveAccessRequestRequest": ".approveaccessrequestop",
    "ApproveAccessRequestRequestTypedDict": ".approveaccessrequestop",
    "ApproveAccessRequestResponseResponse": ".approveaccessrequestop",
    "ApproveAccessRequestResponseResponseTypedDict": ".approveaccessrequestop",
    "ApproveAccessRequestResponse": ".approveaccessrequestresponse",
    "ApproveAccessRequestResponseTypedDict": ".approveaccessrequestresponse",
    "AttachDocumentPolicyRequest": ".attachdocumentpolicyop",
    "AttachDocumentPolicyRequestTypedDict": ".attachdocumentpolicyop",
    "AttachDocumentPolicyResponse": ".attachdocumentpolicyop",
    "AttachDocumentPolicyResponseTypedDict": ".attachdocumentpolicyop",
    "AttachPolicyRequest": ".attachdocumentpolicyop",
    "AttachPolicyRequestTypedDict": ".attachdocumentpolicyop",
    "CheckAccessRequestStatusRequest": ".checkaccessrequeststatusop",
    "CheckAccessRequestStatusRequestTypedDict": ".checkaccessrequeststatusop",
    "CheckAccessRequestStatusResponseResponse": ".checkaccessrequeststatusop",
    "CheckAccessRequestStatusResponseResponseTypedDict": ".checkaccessrequeststatusop",
    "CheckAccessRequestStatusResponse": ".checkaccessrequeststatusresponse",
    "CheckAccessRequestStatusResponseTypedDict": ".checkaccessrequeststatusresponse",
    "CreateAccessRequestCreateAccessRequestRequest": ".createaccessrequestop",
    "CreateAccessRequestCreateAccessRequestRequestTypedDict": ".createaccessrequestop",
    "CreateAccessRequestRequest": ".createaccessrequestop",
    "CreateAccessRequestRequestTypedDict": ".createaccessrequestop",
    "CreateAccessRequestResponseResponse": ".createaccessrequestop",
    "CreateAccessRequestResponseResponseTypedDict": ".createaccessrequestop",
    "CreateAccessRequestResponse": ".createaccessrequestresponse",
    "CreateAccessRequestResponseTypedDict": ".createaccessrequestresponse",
    "CreateAPIKeyResponseResponse": ".createapikeyop",
    "CreateAPIKeyResponseResponseTypedDict": ".createapikeyop",
    "CreateAPIKeyRequest": ".createapikeyrequest",
    "CreateAPIKeyRequestTypedDict": ".createapikeyrequest",
    "CreateAPIKeyResponse": ".createapikeyresponse",
    "CreateAPIKeyResponseTypedDict": ".createapikeyresponse",
    "CreateDocumentResponseResponse": ".createdocumentop",
    "CreateDocumentResponseResponseTypedDict": ".createdocumentop",
    "CreateDocumentRequest": ".createdocumentrequest",
    "CreateDocumentRequestPayload": ".createdocumentrequest",
    "CreateDocumentRequestPayloadTypedDict": ".createdocumentrequest",
    "CreateDocumentRequestTypedDict": ".createdocumentrequest",
    "CreateDocumentResponse": ".createdocumentresponse",
    "CreateDocumentResponseTypedDict": ".createdocumentresponse",
    "CreateDocumentVersionRequest": ".createdocumentversionop",
    "CreateDocumentVersionRequestTypedDict": ".createdocumentversionop",
    "CreateDocumentVersionResponse": ".createdocumentversionop",
    "CreateDocumentVersionResponseTypedDict": ".createdocumentversionop",
    "CreateOrganizationInviteCreateOrganizationInviteRequest": ".createorganizationinviteop",
    "CreateOrganizationInviteCreateOrganizationInviteRequestTypedDict": ".createorganizationinviteop",
    "CreateOrganizationInviteRequest": ".createorganizationinviteop",
    "CreateOrganizationInviteRequestTypedDict": ".createorganizationinviteop",
    "CreateOrganizationInviteResponseResponse": ".createorganizationinviteop",
    "CreateOrganizationInviteResponseResponseTypedDict": ".createorganizationinviteop",
    "CreateOrganizationInviteResponse": ".createorganizationinviteresponse",
    "CreateOrganizationInviteResponseTypedDict": ".createorganizationinviteresponse",
    "CreateShareLinkCreateShareLinkRequest": ".createsharelinkop",
    "CreateShareLinkCreateShareLinkRequestTypedDict": ".createsharelinkop",
    "CreateShareLinkRequest": ".createsharelinkop",
    "CreateShareLinkRequestTypedDict": ".createsharelinkop",
    "CreateShareLinkResponseResponse": ".createsharelinkop",
    "CreateShareLinkResponseResponseTypedDict": ".createsharelinkop",
    "CreateShareLinkResponse": ".createsharelinkresponse",
    "CreateShareLinkResponseTypedDict": ".createsharelinkresponse",
    "CreateVersionRequest": ".createversionrequest",
    "CreateVersionRequestPayload": ".createversionrequest",
    "CreateVersionRequestPayloadTypedDict": ".createversionrequest",
    "CreateVersionRequestTypedDict": ".createversionrequest",
    "DailyUsage": ".dailyusage",
    "DailyUsageTypedDict": ".dailyusage",
    "DeleteAPIKeyQuotaRequest": ".deleteapikeyquotaop",
    "DeleteAPIKeyQuotaRequestTypedDict": ".deleteapikeyquotaop",
    "DeleteAPIKeyQuotaResponseResponse": ".deleteapikeyquotaop",
    "DeleteAPIKeyQuotaResponseResponseTypedDict": ".deleteapikeyquotaop",
    "DeleteAPIKeyQuotaResponse": ".deleteapikeyquotaresponse",
    "DeleteAPIKeyQuotaResponseTypedDict": ".deleteapikeyquotaresponse",
    "DenyAccessRequestDenyAccessRequestRequest": ".denyaccessrequestop",
    "DenyAccessRequestDenyAccessRequestRequestTypedDict": ".denyaccessrequestop",
    "DenyAccessRequestRequest": ".denyaccessrequestop",
    "DenyAccessRequestRequestTypedDict": ".denyaccessrequestop",
    "DenyAccessRequestResponseResponse": ".denyaccessrequestop",
    "DenyAccessRequestResponseResponseTypedDict": ".denyaccessrequestop",
    "DenyAccessRequestResponse": ".denyaccessrequestresponse",
    "DenyAccessRequestResponseTypedDict": ".denyaccessrequestresponse",
    "DetachDocumentPolicyRequest": ".detachdocumentpolicyop",
    "DetachDocumentPolicyRequestTypedDict": ".detachdocumentpolicyop",
    "DetachDocumentPolicyResponse": ".detachdocumentpolicyop",
    "DetachDocumentPolicyResponseTypedDict": ".detachdocumentpolicyop",
    "Document": ".document",
    "DocumentTypedDict": ".document",
    "DocumentOwnership": ".documentownership",
    "DocumentPermissionSet": ".documentpermissionset",
    "DocumentPermissionSetTypedDict": ".documentpermissionset",
    "DocumentPolicy": ".documentpolicy",
    "DocumentPolicyTypedDict": ".documentpolicy",
    "DocumentRole": ".documentrole",
    "DocumentTrashState": ".documenttrashstate",
    "DuplicateDocument": ".duplicatedocument",
    "DuplicateDocumentTypedDict": ".duplicatedocument",
    "Empty": ".empty",
    "EmptyTypedDict": ".empty",
    "ErrorDetail": ".errordetail",
    "ErrorDetailTypedDict": ".errordetail",
    "Reason": ".errordetail",
    "Code": ".errorresponse",
    "ExportDocumentRequest": ".exportdocumentop",
    "ExportDocumentRequestTypedDict": ".exportdocumentop",
    "ExportDocumentResponseResponse": ".exportdocumentop",
    "ExportDocumentResponseResponseTypedDict": ".exportdocumentop",
    "ExportDocumentResponse": ".exportdocumentresponse",
    "ExportDocumentResponseTypedDict": ".exportdocumentresponse",
    "GeneralAccessLevel": ".generalaccesslevel",
    "GenerateDocumentEntryPageRequest": ".generatedocumententrypageop",
    "GenerateDocumentEntryPageRequestTypedDict": ".generatedocumententrypageop",
    "GenerateDocumentEntryPageResponse": ".generatedocumententrypageop",
    "GenerateDocumentEntryPageResponseTypedDict": ".generatedocumententrypageop",
    "GenerateEntryPageResponse": ".generateentrypageresponse",
    "GenerateEntryPageResponseTypedDict": ".generateentrypageresponse",
    "GetDocumentRequest": ".getdocumentop",
    "GetDocumentRequestTypedDict": ".getdocumentop",
    "GetDocumentResponseResponse": ".getdocumentop",
    "GetDocumentResponseResponseTypedDict": ".getdocumentop",
    "GetDocumentQuotaResponseResponse": ".getdocumentquotaop",
    "GetDocumentQuotaResponseResponseTypedDict": ".getdocumentquotaop",
    "GetDocumentQuotaResponse": ".getdocumentquotaresponse",
    "GetDocumentQuotaResponseTypedDict": ".getdocumentquotaresponse",
    "GetDocumentResponse": ".getdocumentresponse",
    "GetDocumentResponseTypedDict": ".getdocumentresponse",
    "GetDocumentTimelineRequest": ".getdocumenttimelineop",
    "GetDocumentTimelineRequestTypedDict": ".getdocumenttimelineop",
    "GetDocumentTimelineResponse": ".getdocumenttimelineop",
    "GetDocumentTimelineResponseTypedDict": ".getdocumenttimelineop",
    "GetGeneralAccessRequest": ".getgeneralaccessop",
    "GetGeneralAccessRequestTypedDict": ".getgeneralaccessop",
    "GetGeneralAccessResponseResponse": ".getgeneralaccessop",
    "GetGeneralAccessResponseResponseTypedDict": ".getgeneralaccessop",
    "GetGeneralAccessResponse": ".getgeneralaccessresponse",
    "GetGeneralAccessResponseTypedDict": ".getgeneralaccessresponse",
    "GetMeResponseResponse": ".getmeop",
    "GetMeResponseResponseTypedDict": ".getmeop",
    "GetMeResponse": ".getmeresponse",
    "GetMeResponseTypedDict": ".getmeresponse",
    "GetOrganizationRequest": ".getorganizationop",
    "GetOrganizationRequestTypedDict": ".getorganizationop",
    "GetOrganizationResponseResponse": ".getorganizationop",
    "GetOrganizationResponseResponseTypedDict": ".getorganizationop",
    "GetOrganizationQuotaRequest": ".getorganizationquotaop",
    "GetOrganizationQuotaRequestTypedDict": ".getorganizationquotaop",
    "GetOrganizationQuotaResponseResponse": ".getorganizationquotaop",
    "GetOrganizationQuotaResponseResponseTypedDict": ".getorganizationquotaop",
    "GetOrganizationQuotaResponse": ".getorganizationquotaresponse",
    "GetOrganizationQuotaResponseTypedDict": ".getorganizationquotaresponse",
    "GetOrganizationResponse": ".getorganizationresponse",
    "GetOrganizationResponseTypedDict": ".getorganizationresponse",
    "GetTimelineResponse": ".gettimelineresponse",
    "GetTimelineResponseTypedDict": ".gettimelineresponse",
    "GetUsageHistoryRequest": ".getusagehistoryop",
    "GetUsageHistoryRequestTypedDict": ".getusagehistoryop",
    "GetUsageHistoryResponseResponse": ".getusagehistoryop",
    "GetUsageHistoryResponseResponseTypedDict": ".getusagehistoryop",
    "GetUsageHistoryResponse": ".getusagehistoryresponse",
    "GetUsageHistoryResponseTypedDict": ".getusagehistoryresponse",
    "GetUserPreferencesResponseResponse": ".getuserpreferencesop",
    "GetUserPreferencesResponseResponseTypedDict": ".getuserpreferencesop",
    "GetUserPreferencesResponse": ".getuserpreferencesresponse",
    "GetUserPreferencesResponseTypedDict": ".getuserpreferencesresponse",
    "GetVersionRequest": ".getversionop",
    "GetVersionRequestTypedDict": ".getversionop",
    "GetVersionResponse": ".getversionop",
    "GetVersionResponseTypedDict": ".getversionop",
    "GrantDocumentAccessGrantDocumentAccessRequest": ".grantdocumentaccessop",
    "GrantDocumentAccessGrantDocumentAccessRequestTypedDict": ".grantdocumentaccessop",
    "GrantDocumentAccessRequest": ".grantdocumentaccessop",
    "GrantDocumentAccessRequestTypedDict": ".grantdocumentaccessop",
    "GrantDocumentAccessResponseResponse": ".grantdocumentaccessop",
    "GrantDocumentAccessResponseResponseTypedDict": ".grantdocumentaccessop",
    "GrantDocumentAccessResponse": ".grantdocumentaccessresponse",
    "GrantDocumentAccessResponseTypedDict": ".grantdocumentaccessresponse",
    "InspectAccessResponse": ".inspectaccessresponse",
    "InspectAccessResponseTypedDict": ".inspectaccessresponse",
    "InspectDocumentAccessRequest": ".inspectdocumentaccessop",
    "InspectDocumentAccessRequestTypedDict": ".inspectdocumentaccessop",
    "InspectDocumentAccessResponse": ".inspectdocumentaccessop",
    "InspectDocumentAccessResponseTypedDict": ".inspectdocumentaccessop",
    "ListAccessRequestsRequest": ".listaccessrequestsop",
    "ListAccessRequestsRequestTypedDict": ".listaccessrequestsop",
    "ListAccessRequestsResponseResponse": ".listaccessrequestsop",
    "ListAccessRequestsResponseResponseTypedDict": ".listaccessrequestsop",
    "ListAccessRequestsResponse": ".listaccessrequestsresponse",
    "ListAccessRequestsResponseTypedDict": ".listaccessrequestsresponse",
    "ListAPIKeyQuotasRequest": ".listapikeyquotasop",
    "ListAPIKeyQuotasRequestTypedDict": ".listapikeyquotasop",
    "ListAPIKeyQuotasResponseResponse": ".listapikeyquotasop",
    "ListAPIKeyQuotasResponseResponseTypedDict": ".listapikeyquotasop",
    "ListAPIKeyQuotasResponse": ".listapikeyquotasresponse",
    "ListAPIKeyQuotasResponseTypedDict": ".listapikeyquotasresponse",
    "ListAPIKeysRequest": ".listapikeysop",
    "ListAPIKeysRequestTypedDict": ".listapikeysop",
    "ListAPIKeysResponseResponse": ".listapikeysop",
    "ListAPIKeysResponseResponseTypedDict": ".listapikeysop",
    "ListAPIKeysResponse": ".listapikeysresponse",
    "ListAPIKeysResponseTypedDict": ".listapikeysresponse",
    "ListDocumentAccessRequest": ".listdocumentaccessop",
    "ListDocumentAccessRequestTypedDict": ".listdocumentaccessop",
    "ListDocumentAccessResponseResponse": ".listdocumentaccessop",
    "ListDocumentAccessResponseResponseTypedDict": ".listdocumentaccessop",
    "ListDocumentAccessResponse": ".listdocumentaccessresponse",
    "ListDocumentAccessResponseTypedDict": ".listdocumentaccessresponse",
    "ListDocumentDuplicatesRequest": ".listdocumentduplicatesop",
    "ListDocumentDuplicatesRequestTypedDict": ".listdocumentduplicatesop",
    "ListDocumentDuplicatesResponseResponse": ".listdocumentduplicatesop",
    "ListDocumentDuplicatesResponseResponseTypedDict": ".listdocumentduplicatesop",
    "ListDocumentDuplicatesResponse": ".listdocumentduplicatesresponse",
    "ListDocumentDuplicatesResponseTypedDict": ".listdocumentduplicatesresponse",
    "ListDocumentPoliciesRequest": ".listdocumentpoliciesop",
    "ListDocumentPoliciesRequestTypedDict": ".listdocumentpoliciesop",
    "ListDocumentPoliciesResponseResponse": ".listdocumentpoliciesop",
    "ListDocumentPoliciesResponseResponseTypedDict": ".listdocumentpoliciesop",
    "ListDocumentPoliciesResponse": ".listdocumentpoliciesresponse",
    "ListDocumentPoliciesResponseTypedDict": ".listdocumentpoliciesresponse",
    "ListDocumentsRequest": ".listdocumentsop",
    "ListDocumentsRequestTypedDict": ".listdocumentsop",
    "ListDocumentsResponseResponse": ".listdocumentsop",
    "ListDocumentsResponseResponseTypedDict": ".listdocumentsop",
    "ListDocumentsResponse": ".listdocumentsresponse",
    "ListDocumentsResponseTypedDict": ".listdocumentsresponse",
    "ListDocumentVersionsRequest": ".listdocumentversionsop",
    "ListDocumentVersionsRequestTypedDict": ".listdocumentversionsop",
    "ListDocumentVersionsResponse": ".listdocumentversionsop",
    "ListDocumentVersionsResponseTypedDict": ".listdocumentversionsop",
    "ListOrganizationInvitesRequest": ".listorganizationinvitesop",
    "ListOrganizationInvitesRequestTypedDict": ".listorganizationinvitesop",
    "ListOrganizationInvitesResponseResponse": ".listorganizationinvitesop",
    "ListOrganizationInvitesResponseResponseTypedDict": ".listorganizationinvitesop",
    "ListOrganizationInvitesResponse": ".listorganizationinvitesresponse",
    "ListOrganizationInvitesResponseTypedDict": ".listorganizationinvitesresponse",
    "ListOrganizationMembersRequest": ".listorganizationmembersop",
    "ListOrganizationMembersRequestTypedDict": ".listorganizationmembersop",
    "ListOrganizationMembersResponseResponse": ".listorganizationmembersop",
    "ListOrganizationMembersResponseResponseTypedDict": ".listorganizationmembersop",
    "ListOrganizationMembersResponse": ".listorganizationmembersresponse",
    "ListOrganizationMembersResponseTypedDict": ".listorganizationmembersresponse",
    "ListOrganizationsRequest": ".listorganizationsop",
    "ListOrganizationsRequestTypedDict": ".listorganizationsop",
    "ListOrganizationsResponseResponse": ".listorganizationsop",
    "ListOrganizationsResponseResponseTypedDict": ".listorganizationsop",
    "ListOrganizationsResponse": ".listorganizationsresponse",
    "ListOrganizationsResponseTypedDict": ".listorganizationsresponse",
    "ListVersionsResponse": ".listversionsresponse",
    "ListVersionsResponseTypedDict": ".listversionsresponse",
    "Organization": ".organization",
    "OrganizationTypedDict": ".organization",
    "OrganizationInvite": ".organizationinvite",
    "OrganizationInviteTypedDict": ".organizationinvite",
    "OrganizationInviteStatus": ".organizationinvitestatus",
    "OrganizationMember": ".organizationmember",
    "OrganizationMemberTypedDict": ".organizationmember",
    "OrganizationQuota": ".organizationquota",
    "OrganizationQuotaTypedDict": ".organizationquota",
    "OrganizationRole": ".organizationrole",
    "Pagination": ".pagination",
    "PaginationTypedDict": ".pagination",
    "Policy": ".policy",
    "PolicyTypedDict": ".policy",
    "ProcessDocumentProcessDocumentRequest": ".processdocumentop",
    "ProcessDocumentProcessDocumentRequestTypedDict": ".processdocumentop",
    "ProcessDocumentRequest": ".processdocumentop",
    "ProcessDocumentRequestTypedDict": ".processdocumentop",
    "ProcessDocumentResponseResponse": ".processdocumentop",
    "ProcessDocumentResponseResponseTypedDict": ".processdocumentop",
    "ProcessDocumentResponse": ".processdocumentresponse",
    "ProcessDocumentResponseTypedDict": ".processdocumentresponse",
    "ProcessingOutcome": ".processingoutcome",
    "ProcessingStatus": ".processingstatus",
    "QuotaTier": ".quotatier",
    "Recipient": ".recipient",
    "RecipientTypedDict": ".recipient",
    "RecipientGrant": ".recipientgrant",
    "RecipientGrantTypedDict": ".recipientgrant",
    "RecipientType": ".recipienttype",
    "RemoveOrganizationMemberRequest": ".removeorganizationmemberop",
    "RemoveOrganizationMemberRequestTypedDict": ".removeorganizationmemberop",
    "RemoveOrganizationMemberResponseResponse": ".removeorganizationmemberop",
    "RemoveOrganizationMemberResponseResponseTypedDict": ".removeorganizationmemberop",
    "RemoveOrganizationMemberResponse": ".removeorganizationmemberresponse",
    "RemoveOrganizationMemberResponseTypedDict": ".removeorganizationmemberresponse",
    "ResendOrganizationInviteRequest": ".resendorganizationinviteop",
    "ResendOrganizationInviteRequestTypedDict": ".resendorganizationinviteop",
    "ResendOrganizationInviteResendOrganizationInviteRequest": ".resendorganizationinviteop",
    "ResendOrganizationInviteResendOrganizationInviteRequestTypedDict": ".resendorganizationinviteop",
    "ResendOrganizationInviteResponseResponse": ".resendorganizationinviteop",
    "ResendOrganizationInviteResponseResponseTypedDict": ".resendorganizationinviteop",
    "ResendOrganizationInviteResponse": ".resendorganizationinviteresponse",
    "ResendOrganizationInviteResponseTypedDict": ".resendorganizationinviteresponse",
    "RevokeAPIKeyRequest": ".revokeapikeyop",
    "RevokeAPIKeyRequestTypedDict": ".revokeapikeyop",
    "RevokeAPIKeyResponseResponse": ".revokeapikeyop",
    "RevokeAPIKeyResponseResponseTypedDict": ".revokeapikeyop",
    "RevokeAPIKeyRevokeAPIKeyRequest": ".revokeapikeyop",
    "RevokeAPIKeyRevokeAPIKeyRequestTypedDict": ".revokeapikeyop",
    "RevokeAPIKeyResponse": ".revokeapikeyresponse",
    "RevokeAPIKeyResponseTypedDict": ".revokeapikeyresponse",
    "RevokeDocumentAccessRequest": ".revokedocumentaccessop",
    "RevokeDocumentAccessRequestTypedDict": ".revokedocumentaccessop",
    "RevokeDocumentAccessResponseResponse": ".revokedocumentaccessop",
    "RevokeDocumentAccessResponseResponseTypedDict": ".revokedocumentaccessop",
    "RevokeDocumentAccessResponse": ".revokedocumentaccessresponse",
    "RevokeDocumentAccessResponseTypedDict": ".revokedocumentaccessresponse",
    "RevokeOrganizationInviteRequest": ".revokeorganizationinviteop",
    "RevokeOrganizationInviteRequestTypedDict": ".revokeorganizationinviteop",
    "RevokeOrganizationInviteResponseResponse": ".revokeorganizationinviteop",
    "RevokeOrganizationInviteResponseResponseTypedDict": ".revokeorganizationinviteop",
    "RevokeOrganizationInviteRevokeOrganizationInviteRequest": ".revokeorganizationinviteop",
    "RevokeOrganizationInviteRevokeOrganizationInviteRequestTypedDict": ".revokeorganizationinviteop",
    "RevokeOrganizationInviteResponse": ".revokeorganizationinviteresponse",
    "RevokeOrganizationInviteResponseTypedDict": ".revokeorganizationinviteresponse",
    "Security": ".security",
    "SecurityTypedDict": ".security",
    "SetAPIKeyQuotaRequest": ".setapikeyquotaop",
    "SetAPIKeyQuotaRequestTypedDict": ".setapikeyquotaop",
    "SetAPIKeyQuotaResponseResponse": ".setapikeyquotaop",
    "SetAPIKeyQuotaResponseResponseTypedDict": ".setapikeyquotaop",
    "SetAPIKeyQuotaSetAPIKeyQuotaRequest": ".setapikeyquotaop",
    "SetAPIKeyQuotaSetAPIKeyQuotaRequestTypedDict": ".setapikeyquotaop",
    "SetAPIKeyQuotaResponse": ".setapikeyquotaresponse",
    "SetAPIKeyQuotaResponseTypedDict": ".setapikeyquotaresponse",
    "SetGeneralAccessRequest": ".setgeneralaccessop",
    "SetGeneralAccessRequestTypedDict": ".setgeneralaccessop",
    "SetGeneralAccessResponseResponse": ".setgeneralaccessop",
    "SetGeneralAccessResponseResponseTypedDict": ".setgeneralaccessop",
    "SetGeneralAccessSetGeneralAccessRequest": ".setgeneralaccessop",
    "SetGeneralAccessSetGeneralAccessRequestTypedDict": ".setgeneralaccessop",
    "SetGeneralAccessResponse": ".setgeneralaccessresponse",
    "SetGeneralAccessResponseTypedDict": ".setgeneralaccessresponse",
    "ShareLink": ".sharelink",
    "ShareLinkTypedDict": ".sharelink",
    "Subject": ".subject",
    "SubjectTypedDict": ".subject",
    "SubjectType": ".subjecttype",
    "TimelineEvent": ".timelineevent",
    "TimelineEventTypedDict": ".timelineevent",
    "TimelineEventType": ".timelineeventtype",
    "TransferDocumentOwnershipRequest": ".transferdocumentownershipop",
    "TransferDocumentOwnershipRequestTypedDict": ".transferdocumentownershipop",
    "TransferDocumentOwnershipResponseResponse": ".transferdocumentownershipop",
    "TransferDocumentOwnershipResponseResponseTypedDict": ".transferdocumentownershipop",
    "TransferDocumentOwnershipTransferDocumentOwnershipRequest": ".transferdocumentownershipop",
    "TransferDocumentOwnershipTransferDocumentOwnershipRequestTypedDict": ".transferdocumentownershipop",
    "TransferDocumentOwnershipResponse": ".transferdocumentownershipresponse",
    "TransferDocumentOwnershipResponseTypedDict": ".transferdocumentownershipresponse",
    "TrashDocumentRequest": ".trashdocumentop",
    "TrashDocumentRequestTypedDict": ".trashdocumentop",
    "TrashDocumentResponseResponse": ".trashdocumentop",
    "TrashDocumentResponseResponseTypedDict": ".trashdocumentop",
    "TrashDocumentTrashDocumentRequest": ".trashdocumentop",
    "TrashDocumentTrashDocumentRequestTypedDict": ".trashdocumentop",
    "TrashDocumentResponse": ".trashdocumentresponse",
    "TrashDocumentResponseTypedDict": ".trashdocumentresponse",
    "UntrashDocumentRequest": ".untrashdocumentop",
    "UntrashDocumentRequestTypedDict": ".untrashdocumentop",
    "UntrashDocumentResponseResponse": ".untrashdocumentop",
    "UntrashDocumentResponseResponseTypedDict": ".untrashdocumentop",
    "UntrashDocumentUntrashDocumentRequest": ".untrashdocumentop",
    "UntrashDocumentUntrashDocumentRequestTypedDict": ".untrashdocumentop",
    "UntrashDocumentResponse": ".untrashdocumentresponse",
    "UntrashDocumentResponseTypedDict": ".untrashdocumentresponse",
    "UpdateDocumentAccessRequest": ".updatedocumentaccessop",
    "UpdateDocumentAccessRequestTypedDict": ".updatedocumentaccessop",
    "UpdateDocumentAccessResponseResponse": ".updatedocumentaccessop",
    "UpdateDocumentAccessResponseResponseTypedDict": ".updatedocumentaccessop",
    "UpdateDocumentAccessUpdateDocumentAccessRequest": ".updatedocumentaccessop",
    "UpdateDocumentAccessUpdateDocumentAccessRequestTypedDict": ".updatedocumentaccessop",
    "UpdateDocumentAccessResponse": ".updatedocumentaccessresponse",
    "UpdateDocumentAccessResponseTypedDict": ".updatedocumentaccessresponse",
    "UpdateDocumentRequest": ".updatedocumentop",
    "UpdateDocumentRequestTypedDict": ".updatedocumentop",
    "UpdateDocumentResponseResponse": ".updatedocumentop",
    "UpdateDocumentResponseResponseTypedDict": ".updatedocumentop",
    "UpdateDocumentUpdateDocumentRequest": ".updatedocumentop",
    "UpdateDocumentUpdateDocumentRequestTypedDict": ".updatedocumentop",
    "UpdateDocumentResponse": ".updatedocumentresponse",
    "UpdateDocumentResponseTypedDict": ".updatedocumentresponse",
    "UpdateOrganizationMemberRequest": ".updateorganizationmemberop",
    "UpdateOrganizationMemberRequestTypedDict": ".updateorganizationmemberop",
    "UpdateOrganizationMemberResponseResponse": ".updateorganizationmemberop",
    "UpdateOrganizationMemberResponseResponseTypedDict": ".updateorganizationmemberop",
    "UpdateOrganizationMemberUpdateOrganizationMemberRequest": ".updateorganizationmemberop",
    "UpdateOrganizationMemberUpdateOrganizationMemberRequestTypedDict": ".updateorganizationmemberop",
    "UpdateOrganizationMemberResponse": ".updateorganizationmemberresponse",
    "UpdateOrganizationMemberResponseTypedDict": ".updateorganizationmemberresponse",
    "UpdateOrganizationRequest": ".updateorganizationop",
    "UpdateOrganizationRequestTypedDict": ".updateorganizationop",
    "UpdateOrganizationResponseResponse": ".updateorganizationop",
    "UpdateOrganizationResponseResponseTypedDict": ".updateorganizationop",
    "UpdateOrganizationUpdateOrganizationRequest": ".updateorganizationop",
    "UpdateOrganizationUpdateOrganizationRequestTypedDict": ".updateorganizationop",
    "UpdateOrganizationResponse": ".updateorganizationresponse",
    "UpdateOrganizationResponseTypedDict": ".updateorganizationresponse",
    "UpdateVersionRequest": ".updateversionop",
    "UpdateVersionRequestTypedDict": ".updateversionop",
    "UpdateVersionResponse": ".updateversionop",
    "UpdateVersionResponseTypedDict": ".updateversionop",
    "UpdateVersionUpdateVersionRequest": ".updateversionop",
    "UpdateVersionUpdateVersionRequestTypedDict": ".updateversionop",
    "User": ".user",
    "UserTypedDict": ".user",
    "Value": ".value",
    "ValueTypedDict": ".value",
    "Version": ".version",
    "VersionTypedDict": ".version",
    "VersionRef": ".versionref",
    "VersionRefTypedDict": ".versionref",
}


def __getattr__(attr_name: str) -> Any:
    return lazy_getattr(
        attr_name, package=__package__, dynamic_imports=_dynamic_imports
    )


def __dir__():
    return lazy_dir(dynamic_imports=_dynamic_imports)
