"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from factify.types import BaseModel, Nullable, OptionalNullable, UNSET, UNSET_SENTINEL
from pydantic import model_serializer
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class APIKeyQuotaTypedDict(TypedDict):
    r"""APIKeyQuota represents per-key quota status."""

    api_key_id: NotRequired[str]
    r"""The API key ID."""
    current_usage: NotRequired[int]
    r"""Current usage for this key in the billing period."""
    is_exceeded: NotRequired[bool]
    r"""Whether this key's quota is exceeded. Only true when limit is set and exceeded."""
    limit: NotRequired[Nullable[int]]
    r"""The configured limit for this key. Not set means no explicit key limit."""
    remaining: NotRequired[int]
    r"""Remaining requests for this key. Only meaningful when limit is set."""


class APIKeyQuota(BaseModel):
    r"""APIKeyQuota represents per-key quota status."""

    api_key_id: Optional[str] = None
    r"""The API key ID."""

    current_usage: Optional[int] = None
    r"""Current usage for this key in the billing period."""

    is_exceeded: Optional[bool] = None
    r"""Whether this key's quota is exceeded. Only true when limit is set and exceeded."""

    limit: OptionalNullable[int] = UNSET
    r"""The configured limit for this key. Not set means no explicit key limit."""

    remaining: Optional[int] = None
    r"""Remaining requests for this key. Only meaningful when limit is set."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(
            ["api_key_id", "current_usage", "is_exceeded", "limit", "remaining"]
        )
        nullable_fields = set(["limit"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m
