"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .document import Document, DocumentTypedDict
from factify.types import BaseModel
from typing_extensions import TypedDict


class UpdateDocumentResponseTypedDict(TypedDict):
    r"""UpdateDocumentResponse contains the updated document."""

    document: DocumentTypedDict
    r"""Document represents a Factify document."""


class UpdateDocumentResponse(BaseModel):
    r"""UpdateDocumentResponse contains the updated document."""

    document: Document
    r"""Document represents a Factify document."""
