"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .dailyusage import DailyUsage, DailyUsageTypedDict
from factify.types import BaseModel, UNSET_SENTINEL
from pydantic import model_serializer
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class GetUsageHistoryResponseTypedDict(TypedDict):
    r"""GetUsageHistoryResponse returns usage history."""

    daily_usage: NotRequired[List[DailyUsageTypedDict]]
    r"""Daily usage records."""
    organization_id: NotRequired[str]
    r"""The organization ID."""
    total_requests: NotRequired[int]
    r"""Total requests in the period."""


class GetUsageHistoryResponse(BaseModel):
    r"""GetUsageHistoryResponse returns usage history."""

    daily_usage: Optional[List[DailyUsage]] = None
    r"""Daily usage records."""

    organization_id: Optional[str] = None
    r"""The organization ID."""

    total_requests: Optional[int] = None
    r"""Total requests in the period."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["daily_usage", "organization_id", "total_requests"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m
