"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from factify.types import BaseModel
from typing_extensions import TypedDict


class DeleteAPIKeyQuotaResponseTypedDict(TypedDict):
    r"""DeleteAPIKeyQuotaResponse confirms deletion. Empty response - success indicated by no error."""


class DeleteAPIKeyQuotaResponse(BaseModel):
    r"""DeleteAPIKeyQuotaResponse confirms deletion. Empty response - success indicated by no error."""
