"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .document import Document, DocumentTypedDict
from factify.types import BaseModel
from typing_extensions import TypedDict


class GetDocumentResponseTypedDict(TypedDict):
    r"""GetDocumentResponse contains the requested document."""

    document: DocumentTypedDict
    r"""Document represents a Factify document."""


class GetDocumentResponse(BaseModel):
    r"""GetDocumentResponse contains the requested document."""

    document: Document
    r"""Document represents a Factify document."""
