"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from datetime import datetime
from factify.types import BaseModel, UNSET_SENTINEL
from pydantic import model_serializer
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class DuplicateDocumentTypedDict(TypedDict):
    r"""DuplicateDocument represents a document that is a visual duplicate."""

    document_id: NotRequired[str]
    r"""Document ID of the duplicate."""
    last_viewed_at: NotRequired[datetime]
    r"""When the caller last viewed this document."""
    title: NotRequired[str]
    r"""Document title."""
    version_id: NotRequired[str]
    r"""Version ID of the duplicate."""
    version_title: NotRequired[str]
    r"""Version title."""


class DuplicateDocument(BaseModel):
    r"""DuplicateDocument represents a document that is a visual duplicate."""

    document_id: Optional[str] = None
    r"""Document ID of the duplicate."""

    last_viewed_at: Optional[datetime] = None
    r"""When the caller last viewed this document."""

    title: Optional[str] = None
    r"""Document title."""

    version_id: Optional[str] = None
    r"""Version ID of the duplicate."""

    version_title: Optional[str] = None
    r"""Version title."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(
            ["document_id", "last_viewed_at", "title", "version_id", "version_title"]
        )
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m
