"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .organizationinvite import OrganizationInvite, OrganizationInviteTypedDict
from factify.types import BaseModel
from typing_extensions import TypedDict


class CreateOrganizationInviteResponseTypedDict(TypedDict):
    r"""CreateOrganizationInviteResponse contains the created invitation."""

    invite: OrganizationInviteTypedDict
    r"""OrganizationInvite represents an invitation to join an organization.
    accepted_fields_consistency // accepted_at and accepted_by must both be set or both be unset

    """


class CreateOrganizationInviteResponse(BaseModel):
    r"""CreateOrganizationInviteResponse contains the created invitation."""

    invite: OrganizationInvite
    r"""OrganizationInvite represents an invitation to join an organization.
    accepted_fields_consistency // accepted_at and accepted_by must both be set or both be unset

    """
