"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .revokedocumentaccessresponse import (
    RevokeDocumentAccessResponse,
    RevokeDocumentAccessResponseTypedDict,
)
from factify.types import BaseModel
from factify.utils import FieldMetadata, PathParamMetadata
from typing import Dict, List
from typing_extensions import Annotated, TypedDict


class RevokeDocumentAccessRequestTypedDict(TypedDict):
    document_id: str
    r"""Document ID."""
    recipient_id: str
    r"""Recipient ID (TypeID: user_xxx or bot_xxx)."""


class RevokeDocumentAccessRequest(BaseModel):
    document_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""Document ID."""

    recipient_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""Recipient ID (TypeID: user_xxx or bot_xxx)."""


class RevokeDocumentAccessResponseResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: RevokeDocumentAccessResponseTypedDict


class RevokeDocumentAccessResponseResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: RevokeDocumentAccessResponse
