"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .denyaccessrequestresponse import (
    DenyAccessRequestResponse,
    DenyAccessRequestResponseTypedDict,
)
from factify.types import BaseModel
from factify.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing import Dict, List
from typing_extensions import Annotated, TypedDict


class DenyAccessRequestDenyAccessRequestRequestTypedDict(TypedDict):
    r"""DenyAccessRequestRequest denies an access request."""


class DenyAccessRequestDenyAccessRequestRequest(BaseModel):
    r"""DenyAccessRequestRequest denies an access request."""


class DenyAccessRequestRequestTypedDict(TypedDict):
    document_id: str
    r"""Document ID."""
    access_request_id: str
    r"""Access request ID to deny."""
    body: DenyAccessRequestDenyAccessRequestRequestTypedDict


class DenyAccessRequestRequest(BaseModel):
    document_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""Document ID."""

    access_request_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""Access request ID to deny."""

    body: Annotated[
        DenyAccessRequestDenyAccessRequestRequest,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]


class DenyAccessRequestResponseResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: DenyAccessRequestResponseTypedDict


class DenyAccessRequestResponseResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: DenyAccessRequestResponse
