"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .createsharelinkresponse import (
    CreateShareLinkResponse,
    CreateShareLinkResponseTypedDict,
)
from factify.types import BaseModel
from factify.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing import Dict, List
from typing_extensions import Annotated, TypedDict


class CreateShareLinkCreateShareLinkRequestTypedDict(TypedDict):
    r"""CreateShareLinkRequest creates a share link for a document."""


class CreateShareLinkCreateShareLinkRequest(BaseModel):
    r"""CreateShareLinkRequest creates a share link for a document."""


class CreateShareLinkRequestTypedDict(TypedDict):
    document_id: str
    r"""Document ID."""
    body: CreateShareLinkCreateShareLinkRequestTypedDict


class CreateShareLinkRequest(BaseModel):
    document_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""Document ID."""

    body: Annotated[
        CreateShareLinkCreateShareLinkRequest,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]


class CreateShareLinkResponseResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: CreateShareLinkResponseTypedDict


class CreateShareLinkResponseResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: CreateShareLinkResponse
