"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .inspectaccessresponse import InspectAccessResponse, InspectAccessResponseTypedDict
from factify.types import BaseModel
from factify.utils import FieldMetadata, PathParamMetadata
from typing import Dict, List
from typing_extensions import Annotated, TypedDict


class InspectDocumentAccessRequestTypedDict(TypedDict):
    document_id: str
    r"""Document ID."""


class InspectDocumentAccessRequest(BaseModel):
    document_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""Document ID."""


class InspectDocumentAccessResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: InspectAccessResponseTypedDict


class InspectDocumentAccessResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: InspectAccessResponse
