"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from .basesdk import BaseSDK
from .httpclient import AsyncHttpClient, ClientOwner, HttpClient, close_clients
from .sdkconfiguration import SDKConfiguration
from .utils.logger import Logger, get_default_logger
from .utils.retries import RetryConfig
from factify import models, utils
from factify._hooks import SDKHooks
from factify.types import OptionalNullable, UNSET
import httpx
import importlib
import sys
from typing import Any, Callable, Dict, Optional, TYPE_CHECKING, Union, cast
import weakref

if TYPE_CHECKING:
    from factify.accessrequests import AccessRequests
    from factify.api_keys import APIKeys
    from factify.documents import Documents
    from factify.entrypages import EntryPages
    from factify.organizations import Organizations
    from factify.policies import Policies
    from factify.sharing import Sharing
    from factify.timelines import Timelines
    from factify.usage import Usage
    from factify.userpreferences import UserPreferences
    from factify.users import Users
    from factify.versions import Versions


class Factify(BaseSDK):
    r"""Factify API: Factify API enables you to create, manage, and control access to legally-binding documents that replace PDFs.

    ## Authentication

    Bearer authentication header of the form Bearer <token>, where <token> is your auth token.

    ```
    Authorization: Bearer ffy...
    ```

    ## Rate Limiting

    - 1000 requests per minute per API key
    - 100 requests per minute for resource creation (POST)

    ## Errors

    Factify uses conventional HTTP status codes and returns structured error responses
    using the [ConnectRPC error format](https://connectrpc.com/docs/protocol#error-codes):

    ```json
    {
    \"code\": \"invalid_argument\",
    \"message\": \"limit must be positive\",
    \"details\": [
    {
    \"reason\": \"invalid_field_value\",
    \"request_id\": \"req_01arwx4k8xrgqskvxq69gdn019\",
    \"param\": \"limit\"
    }
    ]
    }
    ```

    """

    api_keys: "APIKeys"
    r"""Generate and manage API keys for authentication."""
    documents: "Documents"
    r"""Create and manage legally-binding documents."""
    access_requests: "AccessRequests"
    entry_pages: "EntryPages"
    sharing: "Sharing"
    policies: "Policies"
    r"""Attach and manage access policies for documents."""
    timelines: "Timelines"
    versions: "Versions"
    r"""Document version tracking and management."""
    users: "Users"
    r"""User profile and account information."""
    organizations: "Organizations"
    r"""Create and manage organizations."""
    usage: "Usage"
    r"""Query API usage and quota information for your organization."""
    user_preferences: "UserPreferences"
    _sub_sdk_map = {
        "api_keys": ("factify.api_keys", "APIKeys"),
        "documents": ("factify.documents", "Documents"),
        "access_requests": ("factify.accessrequests", "AccessRequests"),
        "entry_pages": ("factify.entrypages", "EntryPages"),
        "sharing": ("factify.sharing", "Sharing"),
        "policies": ("factify.policies", "Policies"),
        "timelines": ("factify.timelines", "Timelines"),
        "versions": ("factify.versions", "Versions"),
        "users": ("factify.users", "Users"),
        "organizations": ("factify.organizations", "Organizations"),
        "usage": ("factify.usage", "Usage"),
        "user_preferences": ("factify.userpreferences", "UserPreferences"),
    }

    def __init__(
        self,
        bearer_auth: Union[str, Callable[[], str]],
        server_idx: Optional[int] = None,
        url_params: Optional[Dict[str, str]] = None,
        server_url: Optional[str] = None,
        client: Optional[HttpClient] = None,
        async_client: Optional[AsyncHttpClient] = None,
        retry_config: OptionalNullable[RetryConfig] = UNSET,
        timeout_ms: Optional[int] = None,
        debug_logger: Optional[Logger] = None,
    ) -> None:
        r"""Instantiates the SDK configuring it with the provided parameters.

        :param bearer_auth: The bearer_auth required for authentication
        :param server_idx: The index of the server to use for all methods
        :param server_url: The server URL to use for all methods
        :param url_params: Parameters to optionally template the server URL with
        :param client: The HTTP client to use for all synchronous methods
        :param async_client: The Async HTTP client to use for all asynchronous methods
        :param retry_config: The retry configuration to use for all supported methods
        :param timeout_ms: Optional request timeout applied to each operation in milliseconds
        """
        client_supplied = True
        if client is None:
            client = httpx.Client(follow_redirects=True)
            client_supplied = False

        assert issubclass(
            type(client), HttpClient
        ), "The provided client must implement the HttpClient protocol."

        async_client_supplied = True
        if async_client is None:
            async_client = httpx.AsyncClient(follow_redirects=True)
            async_client_supplied = False

        if debug_logger is None:
            debug_logger = get_default_logger()

        assert issubclass(
            type(async_client), AsyncHttpClient
        ), "The provided async_client must implement the AsyncHttpClient protocol."

        security: Any = None
        if callable(bearer_auth):
            # pylint: disable=unnecessary-lambda-assignment
            security = lambda: models.Security(bearer_auth=bearer_auth())
        else:
            security = models.Security(bearer_auth=bearer_auth)

        if server_url is not None:
            if url_params is not None:
                server_url = utils.template_url(server_url, url_params)

        BaseSDK.__init__(
            self,
            SDKConfiguration(
                client=client,
                client_supplied=client_supplied,
                async_client=async_client,
                async_client_supplied=async_client_supplied,
                security=security,
                server_url=server_url,
                server_idx=server_idx,
                retry_config=retry_config,
                timeout_ms=timeout_ms,
                debug_logger=debug_logger,
            ),
            parent_ref=self,
        )

        hooks = SDKHooks()

        # pylint: disable=protected-access
        self.sdk_configuration.__dict__["_hooks"] = hooks

        self.sdk_configuration = hooks.sdk_init(self.sdk_configuration)

        weakref.finalize(
            self,
            close_clients,
            cast(ClientOwner, self.sdk_configuration),
            self.sdk_configuration.client,
            self.sdk_configuration.client_supplied,
            self.sdk_configuration.async_client,
            self.sdk_configuration.async_client_supplied,
        )

    def dynamic_import(self, modname, retries=3):
        for attempt in range(retries):
            try:
                return importlib.import_module(modname)
            except KeyError:
                # Clear any half-initialized module and retry
                sys.modules.pop(modname, None)
                if attempt == retries - 1:
                    break
        raise KeyError(f"Failed to import module '{modname}' after {retries} attempts")

    def __getattr__(self, name: str):
        if name in self._sub_sdk_map:
            module_path, class_name = self._sub_sdk_map[name]
            try:
                module = self.dynamic_import(module_path)
                klass = getattr(module, class_name)
                instance = klass(self.sdk_configuration, parent_ref=self)
                setattr(self, name, instance)
                return instance
            except ImportError as e:
                raise AttributeError(
                    f"Failed to import module {module_path} for attribute {name}: {e}"
                ) from e
            except AttributeError as e:
                raise AttributeError(
                    f"Failed to find class {class_name} in module {module_path} for attribute {name}: {e}"
                ) from e

        raise AttributeError(
            f"'{type(self).__name__}' object has no attribute '{name}'"
        )

    def __dir__(self):
        default_attrs = list(super().__dir__())
        lazy_attrs = list(self._sub_sdk_map.keys())
        return sorted(list(set(default_attrs + lazy_attrs)))

    def __enter__(self):
        return self

    async def __aenter__(self):
        return self

    def __exit__(self, exc_type, exc_val, exc_tb):
        if (
            self.sdk_configuration.client is not None
            and not self.sdk_configuration.client_supplied
        ):
            self.sdk_configuration.client.close()
        self.sdk_configuration.client = None

    async def __aexit__(self, exc_type, exc_val, exc_tb):
        if (
            self.sdk_configuration.async_client is not None
            and not self.sdk_configuration.async_client_supplied
        ):
            await self.sdk_configuration.async_client.aclose()
        self.sdk_configuration.async_client = None
