"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from typing import Literal


ProcessingOutcome = Literal[
    "PROCESSING_OUTCOME_UNSPECIFIED",
    "PROCESSING_OUTCOME_STARTED",
    "PROCESSING_OUTCOME_ALREADY_PROCESSING",
    "PROCESSING_OUTCOME_ALREADY_COMPLETED",
    "PROCESSING_OUTCOME_FAILED",
]
r"""ProcessingOutcome describes the result of a processing trigger request."""
