"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .pagination import Pagination, PaginationTypedDict
from .version import Version, VersionTypedDict
from factify.types import BaseModel, UNSET_SENTINEL
from pydantic import model_serializer
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class ListVersionsResponseTypedDict(TypedDict):
    r"""ListVersionsResponse contains a page of versions."""

    pagination: PaginationTypedDict
    r"""Pagination contains cursor-based pagination metadata.
    Follows Google AIP-158 for pagination field naming.
    """
    items: NotRequired[List[VersionTypedDict]]
    r"""List of versions."""


class ListVersionsResponse(BaseModel):
    r"""ListVersionsResponse contains a page of versions."""

    pagination: Pagination
    r"""Pagination contains cursor-based pagination metadata.
    Follows Google AIP-158 for pagination field naming.
    """

    items: Optional[List[Version]] = None
    r"""List of versions."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["items"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m
