"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from datetime import datetime
from factify.types import BaseModel, UNSET_SENTINEL
from pydantic import model_serializer
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class CreateAPIKeyRequestTypedDict(TypedDict):
    r"""CreateApiKeyRequest contains the data needed to create a new API key."""

    name: str
    r"""Human-readable name for the key (e.g., \"Production\", \"Staging\")."""
    organization_id: str
    r"""Organization ID to create the key for.
    Pattern: org_[0-9a-hjkmnp-tv-z]{26}
    """
    expires_at: NotRequired[datetime]
    r"""Expiration timestamp. If not set, the key does not expire.
    When set, must be in the future and within 1 year.
    Security note: Keys without expiration should be rotated periodically.
    timestamp.gt_now = true
    timestamp.within = 8760h0m0s

    """


class CreateAPIKeyRequest(BaseModel):
    r"""CreateApiKeyRequest contains the data needed to create a new API key."""

    name: str
    r"""Human-readable name for the key (e.g., \"Production\", \"Staging\")."""

    organization_id: str
    r"""Organization ID to create the key for.
    Pattern: org_[0-9a-hjkmnp-tv-z]{26}
    """

    expires_at: Optional[datetime] = None
    r"""Expiration timestamp. If not set, the key does not expire.
    When set, must be in the future and within 1 year.
    Security note: Keys without expiration should be rotated periodically.
    timestamp.gt_now = true
    timestamp.within = 8760h0m0s

    """

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["expires_at"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m
