"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from datetime import datetime
from factify.types import BaseModel
from typing_extensions import TypedDict


class PolicyTypedDict(TypedDict):
    r"""Policy represents a governance policy."""

    created_at: datetime
    r"""Timestamp when policy was created."""
    id: str
    r"""Unique ID for the policy.
    Pattern: pol_[0-9a-hjkmnp-tv-z]{26}
    """
    name: str
    r"""Policy name."""


class Policy(BaseModel):
    r"""Policy represents a governance policy."""

    created_at: datetime
    r"""Timestamp when policy was created."""

    id: str
    r"""Unique ID for the policy.
    Pattern: pol_[0-9a-hjkmnp-tv-z]{26}
    """

    name: str
    r"""Policy name."""
