"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .resendorganizationinviteresponse import (
    ResendOrganizationInviteResponse,
    ResendOrganizationInviteResponseTypedDict,
)
from factify.types import BaseModel
from factify.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing import Dict, List
from typing_extensions import Annotated, TypedDict


class ResendOrganizationInviteResendOrganizationInviteRequestTypedDict(TypedDict):
    r"""ResendOrganizationInviteRequest identifies an invitation to resend."""


class ResendOrganizationInviteResendOrganizationInviteRequest(BaseModel):
    r"""ResendOrganizationInviteRequest identifies an invitation to resend."""


class ResendOrganizationInviteRequestTypedDict(TypedDict):
    organization_id: str
    r"""Organization the invitation belongs to.
    Pattern: org_[0-9a-hjkmnp-tv-z]{26}
    """
    invite_id: str
    r"""Invitation ID to resend.
    Pattern: inv_[0-9a-hjkmnp-tv-z]{26}
    """
    body: ResendOrganizationInviteResendOrganizationInviteRequestTypedDict


class ResendOrganizationInviteRequest(BaseModel):
    organization_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""Organization the invitation belongs to.
    Pattern: org_[0-9a-hjkmnp-tv-z]{26}
    """

    invite_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""Invitation ID to resend.
    Pattern: inv_[0-9a-hjkmnp-tv-z]{26}
    """

    body: Annotated[
        ResendOrganizationInviteResendOrganizationInviteRequest,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]


class ResendOrganizationInviteResponseResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: ResendOrganizationInviteResponseTypedDict


class ResendOrganizationInviteResponseResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: ResendOrganizationInviteResponse
