"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .organization import Organization, OrganizationTypedDict
from factify.types import BaseModel
from typing_extensions import TypedDict


class AcceptOrganizationInviteResponseTypedDict(TypedDict):
    r"""AcceptOrganizationInviteResponse contains the organization the user joined."""

    organization: OrganizationTypedDict
    r"""Organization represents a Factify organization."""


class AcceptOrganizationInviteResponse(BaseModel):
    r"""AcceptOrganizationInviteResponse contains the organization the user joined."""

    organization: Organization
    r"""Organization represents a Factify organization."""
