"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from factify.types import BaseModel
from typing_extensions import TypedDict


class VersionRefTypedDict(TypedDict):
    r"""VersionRef is a lightweight reference to a version."""

    id: str
    r"""Version ID.
    Pattern: ver_[0-9a-hjkmnp-tv-z]{26}
    """


class VersionRef(BaseModel):
    r"""VersionRef is a lightweight reference to a version."""

    id: str
    r"""Version ID.
    Pattern: ver_[0-9a-hjkmnp-tv-z]{26}
    """
