"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .document import Document, DocumentTypedDict
from factify.types import BaseModel
from typing_extensions import TypedDict


class CreateDocumentResponseTypedDict(TypedDict):
    r"""CreateDocumentResponse contains the newly created document."""

    document: DocumentTypedDict
    r"""Document represents a Factify document."""


class CreateDocumentResponse(BaseModel):
    r"""CreateDocumentResponse contains the newly created document."""

    document: Document
    r"""Document represents a Factify document."""
