"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .generalaccesslevel import GeneralAccessLevel
from .setgeneralaccessresponse import (
    SetGeneralAccessResponse,
    SetGeneralAccessResponseTypedDict,
)
from factify.types import BaseModel
from factify.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing import Dict, List
from typing_extensions import Annotated, TypedDict


class SetGeneralAccessSetGeneralAccessRequestTypedDict(TypedDict):
    r"""SetGeneralAccessRequest sets the general access level."""

    general_access_level: GeneralAccessLevel


class SetGeneralAccessSetGeneralAccessRequest(BaseModel):
    r"""SetGeneralAccessRequest sets the general access level."""

    general_access_level: GeneralAccessLevel


class SetGeneralAccessRequestTypedDict(TypedDict):
    document_id: str
    r"""Document ID."""
    body: SetGeneralAccessSetGeneralAccessRequestTypedDict


class SetGeneralAccessRequest(BaseModel):
    document_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""Document ID."""

    body: Annotated[
        SetGeneralAccessSetGeneralAccessRequest,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]


class SetGeneralAccessResponseResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: SetGeneralAccessResponseTypedDict


class SetGeneralAccessResponseResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: SetGeneralAccessResponse
