"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .version import Version, VersionTypedDict
from factify.types import BaseModel
from factify.utils import FieldMetadata, PathParamMetadata
from typing import Dict, List
from typing_extensions import Annotated, TypedDict


class GetVersionRequestTypedDict(TypedDict):
    version_id: str
    r"""Version ID to retrieve.
    Pattern: ver_[0-9a-hjkmnp-tv-z]{26}
    """


class GetVersionRequest(BaseModel):
    version_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""Version ID to retrieve.
    Pattern: ver_[0-9a-hjkmnp-tv-z]{26}
    """


class GetVersionResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: VersionTypedDict


class GetVersionResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: Version
