"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .organizationmember import OrganizationMember, OrganizationMemberTypedDict
from factify.types import BaseModel
from typing_extensions import TypedDict


class UpdateOrganizationMemberResponseTypedDict(TypedDict):
    r"""UpdateOrganizationMemberResponse contains the updated member."""

    member: OrganizationMemberTypedDict
    r"""OrganizationMember represents a member of an organization."""


class UpdateOrganizationMemberResponse(BaseModel):
    r"""UpdateOrganizationMemberResponse contains the updated member."""

    member: OrganizationMember
    r"""OrganizationMember represents a member of an organization."""
