"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .getuserpreferencesresponse import (
    GetUserPreferencesResponse,
    GetUserPreferencesResponseTypedDict,
)
from factify.types import BaseModel
from typing import Dict, List
from typing_extensions import TypedDict


class GetUserPreferencesResponseResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: GetUserPreferencesResponseTypedDict


class GetUserPreferencesResponseResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: GetUserPreferencesResponse
