"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .generalaccesslevel import GeneralAccessLevel
from .recipient import Recipient, RecipientTypedDict
from factify.types import BaseModel, UNSET_SENTINEL
from pydantic import model_serializer
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class ListDocumentAccessResponseTypedDict(TypedDict):
    r"""ListDocumentAccessResponse contains the access list and general access level."""

    document_id: NotRequired[str]
    r"""Document ID."""
    general_access_level: NotRequired[GeneralAccessLevel]
    recipients: NotRequired[List[RecipientTypedDict]]
    r"""Recipients with access."""


class ListDocumentAccessResponse(BaseModel):
    r"""ListDocumentAccessResponse contains the access list and general access level."""

    document_id: Optional[str] = None
    r"""Document ID."""

    general_access_level: Optional[GeneralAccessLevel] = None

    recipients: Optional[List[Recipient]] = None
    r"""Recipients with access."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["document_id", "general_access_level", "recipients"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m
