"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from factify.types import BaseModel, UNSET_SENTINEL
import pydantic
from pydantic import model_serializer
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class DailyUsageTypedDict(TypedDict):
    r"""DailyUsage represents usage for a single day."""

    date_: NotRequired[str]
    r"""The date (YYYY-MM-DD format)."""
    request_count: NotRequired[int]
    r"""Request count for this day."""


class DailyUsage(BaseModel):
    r"""DailyUsage represents usage for a single day."""

    date_: Annotated[Optional[str], pydantic.Field(alias="date")] = None
    r"""The date (YYYY-MM-DD format)."""

    request_count: Optional[int] = None
    r"""Request count for this day."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["date", "request_count"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


try:
    DailyUsage.model_rebuild()
except NameError:
    pass
