"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .createversionrequest import CreateVersionRequest, CreateVersionRequestTypedDict
from .version import Version, VersionTypedDict
from factify.types import BaseModel
from factify.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing import Dict, List
from typing_extensions import Annotated, TypedDict


class CreateDocumentVersionRequestTypedDict(TypedDict):
    document_id: str
    r"""Document ID to create version for.
    Pattern: doc_[0-9a-hjkmnp-tv-z]{26}
    """
    body: CreateVersionRequestTypedDict


class CreateDocumentVersionRequest(BaseModel):
    document_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""Document ID to create version for.
    Pattern: doc_[0-9a-hjkmnp-tv-z]{26}
    """

    body: Annotated[
        CreateVersionRequest,
        FieldMetadata(request=RequestMetadata(media_type="multipart/form-data")),
    ]


class CreateDocumentVersionResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: VersionTypedDict


class CreateDocumentVersionResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: Version
