"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .apikey import APIKey, APIKeyTypedDict
from factify.types import BaseModel
from typing_extensions import TypedDict


class RevokeAPIKeyResponseTypedDict(TypedDict):
    r"""RevokeApiKeyResponse contains the revoked API key."""

    api_key: APIKeyTypedDict
    r"""ApiKey represents an authentication credential for programmatic API access."""


class RevokeAPIKeyResponse(BaseModel):
    r"""RevokeApiKeyResponse contains the revoked API key."""

    api_key: APIKey
    r"""ApiKey represents an authentication credential for programmatic API access."""
