"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from factify.types import BaseModel, UNSET_SENTINEL
from pydantic import model_serializer
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class GetUserPreferencesResponseTypedDict(TypedDict):
    r"""GetUserPreferencesResponse contains the user's onboarding preferences."""

    has_completed_document_tour: NotRequired[bool]
    r"""Whether the user has completed the document tour."""
    has_completed_hub_onboarding: NotRequired[bool]
    r"""Whether the user has completed the hub onboarding flow."""


class GetUserPreferencesResponse(BaseModel):
    r"""GetUserPreferencesResponse contains the user's onboarding preferences."""

    has_completed_document_tour: Optional[bool] = None
    r"""Whether the user has completed the document tour."""

    has_completed_hub_onboarding: Optional[bool] = None
    r"""Whether the user has completed the hub onboarding flow."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(
            ["has_completed_document_tour", "has_completed_hub_onboarding"]
        )
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m
